@@ -40,6 +40,12 @@ int main(int argc, char *argv[])
     qss.open(QFile::ReadOnly);
     qApp->setStyleSheet(qss.readAll());
 
+//    QGSettings* setting=new QGSettings(QString("org.mate.interface").toLocal8Bit());
+//    QString value=setting->get("font-name").toString();
+//    QFont font;
+//    font.setFamily(value);
+//    qApp->setFont(font);
+
     QString locale = QLocale::system().name();
     QTranslator translator;
     if (locale == "zh_CN"){
@@ -57,21 +63,32 @@ int main(int argc, char *argv[])
     qApp->setStyleSheet(style);
 
     MainWindow w;
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
-
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
-    QDBusReply<int> panelSize=iface.call("GetPanelSize","");
-    if(position==0)
-        w.setGeometry(QRect(0,Style::heightavailable-590,376,590));
-    else if(position==1)
-        w.setGeometry(QRect(0,panelSize,376,590));
-    else if(position==2)
-        w.setGeometry(QRect(panelSize,0,376,590));
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    int panelSize=0;
+    if(fileInfo.exists())
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+        panelSize=gsetting->get("panelsize").toInt();
+    }
     else
-        w.setGeometry(QRect(Style::widthavailable-376,0,376,590));
+    {
+        position=0;
+        panelSize=46;
+    }
+
+    int x=QApplication::primaryScreen()->geometry().x();
+    int y=QApplication::primaryScreen()->geometry().y();
+
+    if(position==0)
+        w.setGeometry(QRect(x,Style::heightavailable-590,376,590));
+    else if(position==1)
+        w.setGeometry(QRect(x,panelSize,376,590));
+    else if(position==2)
+        w.setGeometry(QRect(panelSize,y,376,590));
+    else
+        w.setGeometry(QRect(Style::widthavailable-376,y,376,590));
     app.setActivationWindow(&w);
 
     //注释掉，以保证自启动时不显示界面
