@@ -67,14 +67,25 @@ protected:
     void initWidget();
     void initAppListWidget();//初始化应用列表界面
     void fillAppList();//填充应用列表
+    void getCommonUseAppList();//获取常用应用列表
 
 private Q_SLOTS:
-    void updateListViewSlot();//更新应用列表槽函数
+    /**
+     * @brief 更新单个item槽函数
+     * @param desktopfp为desktop文件路径
+     * @param type为0时表示固定，为1时表示取消固定
+     */
+    void updateListViewSlot(QString desktopfp,int type);
     void execApplication(QString appname);//执行应用程序
+    void removeListItemSlot(QString desktopfp);//删除单个item
+    void removeListAllItemSlot();//删除所有非固定item
+    void updateListViewAllSlot();//更新应用列表槽函数
 
 Q_SIGNALS:
-    void sendUpdateAppListSignal();//向CommonUseWidget发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向CommonUseWidget发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
+    void removeListItemSignal(QString desktopfp);
+    void removeListAllItemSignal();
 };
 
 #endif // FULLCOMMONUSEWIDGET_H
