@@ -218,7 +218,6 @@ void FullFunctionWidget::fillAppList()
     if(!educationlist.isEmpty())
     {
         insertClassificationBtn(tr("Education"));
-
         insertAppList(educationlist);
     }
 
@@ -240,7 +239,7 @@ void FullFunctionWidget::fillAppList()
 
 void FullFunctionWidget::insertClassificationBtn(QString btnname)
 {
-    PushButton* classificationbtn=new PushButton(btnname,scrollarea->width()-12,20);
+    PushButton* classificationbtn=new PushButton(this,btnname,scrollarea->width()-12,20);
     classificationbtn->setFixedSize(scrollarea->width()-12,20);
     scrollareawidLayout->addWidget(classificationbtn);
     classificationbtnlist.append(btnname);
@@ -258,10 +257,9 @@ void FullFunctionWidget::insertAppList(QStringList appnamelist)
         QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appnamelist.at(i));
         data.append(desktopfp);
     }
-
     listview->addData(data);
     connect(listview,SIGNAL(sendItemClickedSignal(QString)),this,SLOT(execApplication(QString)));
-    connect(listview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+    connect(listview,SIGNAL(sendFixedOrUnfixedSignal(QString,int)),this,SIGNAL(sendUpdateAppListSignal(QString,int)));
     connect(listview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
 }
 
@@ -287,56 +285,29 @@ void FullFunctionWidget::execApplication(QString appname)
 void FullFunctionWidget::updateAppListView()
 {
     //刷新应用列表界面
-    for(int index=scrollareawidLayout->count()-1;index>=0;index--)
-    {
-            QLayoutItem* item=scrollareawidLayout->takeAt(index);
-            QWidget* wid=item->widget();
-            scrollareawidLayout->removeWidget(wid);
-            wid->setParent(nullptr);
-            delete wid;
-    }
-
-    fillAppList();
+    QLayoutItem *child;
+     while ((child = scrollareawidLayout->takeAt(0)) != 0) {
+         QWidget* wid=child->widget();
+         scrollareawidLayout->removeWidget(wid);
+         wid->setParent(nullptr);
+         delete wid;
+         delete child;
+     }
+     fillAppList();
 
     //刷新图标列表界面
     Q_FOREACH (QAbstractButton* button, buttonList){
         pBtnGroup->removeButton(button);
     }
     buttonList.clear();
-    for(int index=iconlistscrollareawidLayout->count()-2;index>0;index--)
-    {
-        QLayoutItem* item=iconlistscrollareawidLayout->takeAt(index);
-        QWidget* wid=item->widget();
+    while ((child = iconlistscrollareawidLayout->takeAt(0)) != 0) {
+        QWidget* wid=child->widget();
         iconlistscrollareawidLayout->removeWidget(wid);
         wid->setParent(nullptr);
         delete wid;
+        delete child;
     }
-    for(int i=0;i<classificationbtnlist.size();i++)
-    {
-        FunctionClassifyButton* iconbtn=new FunctionClassifyButton(this,
-                                                                   Style::LeftBtnWidth,
-                                                                   Style::LeftBtnHeight,
-                                                                   Style::LeftIconSize,
-                                                                   Style::LeftFontSize,
-                                                                   iconlist.at(functionnamelist.indexOf(classificationbtnlist.at(i))),
-                                                                   iconlightlist.at(functionnamelist.indexOf(classificationbtnlist.at(i))),
-                                                                   ClassifyBtnHoverBackground,
-                                                                   ClassifyBtnHoverBackground,
-                                                                   2,
-                                                                   classificationbtnlist.at(i),
-                                                                   true,
-                                                                   true);
-        buttonList.append(iconbtn);
-        iconlistscrollareawidLayout->insertWidget(i+1,iconbtn);
-        connect(iconbtn,SIGNAL(buttonClicked(QAbstractButton*)),pBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)));
-    }
-
-    int id=0;
-    Q_FOREACH (QAbstractButton* btn, buttonList) {
-        pBtnGroup->addButton(btn,id++);
-    }
-    iconlistscrollarea->widget()->adjustSize();
-    pBtnGroup->button(0)->click();
+    initIconListScrollArea();
 }
 
 /**
@@ -349,11 +320,6 @@ void FullFunctionWidget::resizeScrollAreaControls()
     int row=0;
     while(row<scrollareawidLayout->count()/2)
     {
-        //分类按钮
-//        QLayoutItem* classificationbtnwidItem=scrollareawidLayout->itemAt(row*2);
-//        QWidget* classificationbtnwid=classificationbtnwidItem->widget();
-//        QPushButton* classificationbtn=qobject_cast<QPushButton*>(classificationbtnwid);
-//        classificationbtn->setFixedSize(scrollarea->width()-32,20);
         //应用界面
         QLayoutItem* widItem=scrollareawidLayout->itemAt(row*2+1);
         QWidget* wid=widItem->widget();
@@ -392,15 +358,20 @@ void FullFunctionWidget::initIconListWidget()
     iconlistLayout->setSpacing(0);
     iconlistWid->setLayout(iconlistLayout);
 
-    iconlistscrollarea=new ClassifyScrollArea();
-    iconlistscrollarea->setFixedSize(Style::LeftBtnWidth,iconlistWid->height());
+    iconlistscrollarea=new ClassifyScrollArea(iconlistWid);
+//    iconlistscrollarea->setFixedSize(Style::LeftBtnWidth,iconlistWid->height());
     iconlistscrollareaWid=new QWidget;
     iconlistscrollareawidLayout=new QVBoxLayout;
     iconlistscrollareawidLayout->setContentsMargins(0,0,0,0);
     iconlistscrollareawidLayout->setSpacing(Style::LeftSpaceBetweenItem);
     iconlistscrollareaWid->setLayout(iconlistscrollareawidLayout);
     iconlistscrollarea->setWidget(iconlistscrollareaWid);
+
+    pIconListTopSpacer=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
+    pIconListBottomSpacer=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
+    iconlistLayout->addItem(pIconListTopSpacer);
     iconlistLayout->addWidget(iconlistscrollarea);
+    iconlistLayout->addItem(pIconListBottomSpacer);
     pBtnGroup=new QButtonGroup(iconlistscrollareaWid);
     initIconListScrollArea();
 }
@@ -410,10 +381,8 @@ void FullFunctionWidget::initIconListWidget()
  */
 void FullFunctionWidget::initIconListScrollArea()
 {
-    pIconListTopSpacer=new QSpacerItem(40,20,QSizePolicy::Fixed,QSizePolicy::Expanding);
-    pIconListBottomSpacer=new QSpacerItem(40,20,QSizePolicy::Fixed,QSizePolicy::Expanding);
-
-    iconlistscrollareawidLayout->addItem(pIconListTopSpacer);
+    iconlistscrollarea->setFixedSize(Style::LeftBtnWidth,
+                                     classificationbtnlist.size()*Style::LeftBtnHeight+(classificationbtnlist.size()-1)*Style::LeftSpaceBetweenItem);
     for(int i=0;i<classificationbtnlist.size();i++)
     {
         FunctionClassifyButton* iconbtn=new FunctionClassifyButton(this,
@@ -433,7 +402,6 @@ void FullFunctionWidget::initIconListScrollArea()
         iconlistscrollareawidLayout->addWidget(iconbtn);
         connect(iconbtn,SIGNAL(buttonClicked(QAbstractButton*)),pBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)));
     }
-    iconlistscrollareawidLayout->addItem(pIconListBottomSpacer);
 
     int id=0;
     Q_FOREACH (QAbstractButton* btn, buttonList) {
@@ -442,7 +410,6 @@ void FullFunctionWidget::initIconListScrollArea()
     connect(pBtnGroup,SIGNAL(buttonClicked(QAbstractButton*)),this,SLOT(btnGroupClickedSlot(QAbstractButton*)));
     iconlistscrollarea->widget()->adjustSize();
     pBtnGroup->button(0)->click();
-
 }
 
 void FullFunctionWidget::btnGroupClickedSlot(QAbstractButton *btn)
@@ -452,8 +419,8 @@ void FullFunctionWidget::btnGroupClickedSlot(QAbstractButton *btn)
     Q_FOREACH (QAbstractButton* button, buttonList) {
 
         FunctionClassifyButton* fcbutton=qobject_cast<FunctionClassifyButton*>(button);
-        QLayoutItem* iconitem=fcbutton->layout()->itemAt(0);
-        QLabel* iconlabel=qobject_cast<QLabel*>(iconitem->widget());
+//        QLayoutItem* iconitem=fcbutton->layout()->itemAt(0);
+//        QLabel* iconlabel=qobject_cast<QLabel*>(iconitem->widget());
         QLayoutItem* textitem=fcbutton->layout()->itemAt(1);
         QLabel* textlabel=qobject_cast<QLabel*>(textitem->widget());
 
@@ -462,57 +429,43 @@ void FullFunctionWidget::btnGroupClickedSlot(QAbstractButton *btn)
             int num=classificationbtnlist.indexOf(textlabel->text());
             if(num!=-1)
             {
-                beforebtnPos=scrollarea->verticalScrollBar()->sliderPosition();
+                beginPos=scrollarea->verticalScrollBar()->sliderPosition();
                 endPos=classificationbtnrowlist.at(num).toInt();
+                scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
                 timer->start(1);
-//                scrollarea->verticalScrollBar()->setSliderPosition(pos);
             }
-
-            QSvgRenderer* svgRender = new QSvgRenderer;
-            svgRender->load(iconlightlist.at(functionnamelist.indexOf(textlabel->text())));
-            QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-            pixmap->fill(Qt::transparent);
-            QPainter p(pixmap);
-            svgRender->render(&p);
-            iconlabel->setPixmap(*pixmap);
-            textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255);");
-            fcbutton->is_pressed=true;
-
+            fcbutton->setChecked(true);
         }
         else{
-            QSvgRenderer* svgRender = new QSvgRenderer;
-            svgRender->load(iconlist.at(functionnamelist.indexOf(textlabel->text())));
-            QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-            pixmap->fill(Qt::transparent);
-            QPainter p(pixmap);
-            svgRender->render(&p);
-            iconlabel->setPixmap(*pixmap);
-            textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255,50%);");
-            fcbutton->is_pressed=false;
+            fcbutton->setChecked(false);
         }
     }
 }
 
 void FullFunctionWidget::timeOutSlot()
 {
+    int speed=0;
+    if(qAbs(endPos-scrollarea->verticalScrollBar()->sliderPosition())<=300)
+        speed=sqrt(qAbs(endPos-scrollarea->verticalScrollBar()->sliderPosition()));
+    else
+    {
+        int height=QApplication::primaryScreen()->geometry().height();
+        speed=height*170/1080;
+    }
+
     if(beginPos<endPos)
     {
-        if(endPos-scrollarea->verticalScrollBar()->sliderPosition()<50)
-            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
-        else
-            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()+50);
+        scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()+speed);
     }
     else
     {
-        if(scrollarea->verticalScrollBar()->sliderPosition()-endPos<50)
-            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
-        else
-            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()-50);
+        scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()-speed);
     }
     if(scrollarea->verticalScrollBar()->sliderPosition()==endPos ||
             scrollarea->verticalScrollBar()->sliderPosition()>=scrollarea->verticalScrollBar()->maximum())
     {
         timer->stop();
+        scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
         connect(scrollarea->verticalScrollBar(),SIGNAL(valueChanged(int)),
                 this,SLOT(valueChangedSlot(int)));
     }
@@ -528,36 +481,13 @@ void FullFunctionWidget::valueChangedSlot(int value)
                 value <classificationbtnrowlist.at(count+1).toInt())
         {
             Q_FOREACH (QAbstractButton* button, buttonList) {
-
                 FunctionClassifyButton* fcbutton=qobject_cast<FunctionClassifyButton*>(button);
-                QLayoutItem* iconitem=fcbutton->layout()->itemAt(0);
-                QLabel* iconlabel=qobject_cast<QLabel*>(iconitem->widget());
-                QLayoutItem* textitem=fcbutton->layout()->itemAt(1);
-                QLabel* textlabel=qobject_cast<QLabel*>(textitem->widget());
-
                 if(count==buttonList.indexOf(button))
                 {
-                    QSvgRenderer* svgRender = new QSvgRenderer;
-                    svgRender->load(iconlightlist.at(functionnamelist.indexOf(textlabel->text())));
-                    QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-                    pixmap->fill(Qt::transparent);
-                    QPainter p(pixmap);
-                    svgRender->render(&p);
-                    iconlabel->setPixmap(*pixmap);
-                    textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255);");
-                    fcbutton->is_pressed=true;
-
+                    fcbutton->setChecked(true);
                 }
                 else{
-                    QSvgRenderer* svgRender = new QSvgRenderer;
-                    svgRender->load(iconlist.at(functionnamelist.indexOf(textlabel->text())));
-                    QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-                    pixmap->fill(Qt::transparent);
-                    QPainter p(pixmap);
-                    svgRender->render(&p);
-                    iconlabel->setPixmap(*pixmap);
-                    textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255,50%);");
-                    fcbutton->is_pressed=false;
+                    fcbutton->setChecked(false);
                 }
             }
             break;
@@ -565,44 +495,44 @@ void FullFunctionWidget::valueChangedSlot(int value)
         else
             count++;
     }
-    if(count==classificationbtnrowlist.count()-1 ||
-            scrollarea->verticalScrollBar()->sliderPosition()>=scrollarea->verticalScrollBar()->maximum())
-    {
-        Q_FOREACH (QAbstractButton* button, buttonList) {
+//    if(count==classificationbtnrowlist.count()-1 ||
+//            scrollarea->verticalScrollBar()->sliderPosition()>=scrollarea->verticalScrollBar()->maximum())
+//    {
+//        Q_FOREACH (QAbstractButton* button, buttonList) {
 
-            FunctionClassifyButton* fcbutton=qobject_cast<FunctionClassifyButton*>(button);
-            QLayoutItem* iconitem=fcbutton->layout()->itemAt(0);
-            QLabel* iconlabel=qobject_cast<QLabel*>(iconitem->widget());
-            QLayoutItem* textitem=fcbutton->layout()->itemAt(1);
-            QLabel* textlabel=qobject_cast<QLabel*>(textitem->widget());
+//            FunctionClassifyButton* fcbutton=qobject_cast<FunctionClassifyButton*>(button);
+//            QLayoutItem* iconitem=fcbutton->layout()->itemAt(0);
+//            QLabel* iconlabel=qobject_cast<QLabel*>(iconitem->widget());
+//            QLayoutItem* textitem=fcbutton->layout()->itemAt(1);
+//            QLabel* textlabel=qobject_cast<QLabel*>(textitem->widget());
 
-            if(classificationbtnrowlist.count()-1==buttonList.indexOf(button))
-            {
-                QSvgRenderer* svgRender = new QSvgRenderer;
-                svgRender->load(iconlightlist.at(functionnamelist.indexOf(textlabel->text())));
-                QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-                pixmap->fill(Qt::transparent);
-                QPainter p(pixmap);
-                svgRender->render(&p);
-                iconlabel->setPixmap(*pixmap);
-                textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255);");
-                fcbutton->is_pressed=true;
+//            if(classificationbtnrowlist.count()-1==buttonList.indexOf(button))
+//            {
+//                QSvgRenderer* svgRender = new QSvgRenderer;
+//                svgRender->load(iconlightlist.at(functionnamelist.indexOf(textlabel->text())));
+//                QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
+//                pixmap->fill(Qt::transparent);
+//                QPainter p(pixmap);
+//                svgRender->render(&p);
+//                iconlabel->setPixmap(*pixmap);
+//                textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255);");
+//                fcbutton->is_pressed=true;
 
-            }
-            else{
-                QSvgRenderer* svgRender = new QSvgRenderer;
-                svgRender->load(iconlist.at(functionnamelist.indexOf(textlabel->text())));
-                QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
-                pixmap->fill(Qt::transparent);
-                QPainter p(pixmap);
-                svgRender->render(&p);
-                iconlabel->setPixmap(*pixmap);
-                textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255,50%);");
-                fcbutton->is_pressed=false;
-            }
-        }
-    }
-    iconlistscrollarea->verticalScrollBar()->setSliderPosition(buttonList.at(count)->pos().y());
+//            }
+//            else{
+//                QSvgRenderer* svgRender = new QSvgRenderer;
+//                svgRender->load(iconlist.at(functionnamelist.indexOf(textlabel->text())));
+//                QPixmap* pixmap = new QPixmap(Style::LeftIconSize,Style::LeftIconSize);
+//                pixmap->fill(Qt::transparent);
+//                QPainter p(pixmap);
+//                svgRender->render(&p);
+//                iconlabel->setPixmap(*pixmap);
+//                textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255,50%);");
+//                fcbutton->is_pressed=false;
+//            }
+//        }
+//    }
+//    iconlistscrollarea->verticalScrollBar()->setSliderPosition(buttonList.at(count)->pos().y());
 }
 
 void FullFunctionWidget::widgetMakeZero()
@@ -616,4 +546,5 @@ void FullFunctionWidget::widgetMakeZero()
             break;
         }
     }
+    scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 }
