@@ -31,6 +31,7 @@
 #include <QPushButton>
 #include <QButtonGroup>
 #include <QTimer>
+#include <QPropertyAnimation>
 #include "src/Interface/ukuimenuinterface.h"
 #include "src/UtilityFunction/scrollarea.h"
 #include "src/UtilityFunction/pushbutton.h"
@@ -87,9 +88,6 @@ private:
     QList<QAbstractButton*> buttonList;
     QButtonGroup* pBtnGroup=nullptr;
 
-    int btnPos=0;
-    int beforebtnPos=0;
-
     //计时器
     QTimer* timer=nullptr;
     int beginPos=0;//滑动条起始位置
@@ -114,7 +112,7 @@ private Q_SLOTS:
     void valueChangedSlot(int value);//滑动条滚动槽函数
 
 Q_SIGNALS:
-    void sendUpdateAppListSignal();//向常用软件模块发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向常用软件模块发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
 };
 
