@@ -153,7 +153,7 @@ void FunctionButtonWidget::recvClassificationBtnList(QStringList list)
                                                    106,
                                                    48,
                                                    19,
-                                                   14,
+                                                   Style::LeftFontSize,
                                                    icondisabledlist.at(row*2+col),
                                                    icondisabledlist.at(row*2+col),
                                                    ClassifyBtnHoverBackground,
@@ -169,7 +169,7 @@ void FunctionButtonWidget::recvClassificationBtnList(QStringList list)
                                                    106,
                                                    48,
                                                    19,
-                                                   14,
+                                                   Style::LeftFontSize,
                                                    iconlist.at(row*2+col),
                                                    iconlightlist.at(row*2+col),
                                                    ClassifyBtnHoverBackground,
