@@ -66,7 +66,7 @@ void FunctionWidget::initAppListWidget()
     mainLayout->addWidget(applistview);
     fillAppListView();
     connect(applistview,SIGNAL(sendItemClickedSignal(QStringList)),this,SLOT(recvItemClickedSlot(QStringList)));
-    connect(applistview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+    connect(applistview,SIGNAL(sendFixedOrUnfixedSignal(QString,int)),this,SIGNAL(sendUpdateAppListSignal(QString,int)));
     connect(applistview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
 
 }
@@ -151,8 +151,6 @@ void FunctionWidget::fillAppListView()
         insertAppList(otherlist);
     }
 
-    m_delegate= new ItemDelegate(this,2);
-    applistview->setItemDelegate(m_delegate);
     applistview->addData(data);
 }
 
