@@ -126,7 +126,6 @@ QStringList UkuiMenuInterface::getDesktopFilePath()
     recursiveSearchFile("/usr/share/applications/");
 
     filePathList.removeAll("/usr/share/applications/peony-folder-handler.desktop");
-    filePathList.removeAll("/usr/share/applications/peony.desktop");
     filePathList.removeAll("/usr/share/applications/gnome-software-local-file.desktop");
     filePathList.removeAll("/usr/share/applications/org.gnome.Software.Editor.desktop");
     filePathList.removeAll("/usr/share/applications/apport-gtk.desktop");
@@ -159,7 +158,6 @@ QStringList UkuiMenuInterface::getDesktopFilePath()
     filePathList.removeAll("/usr/share/applications/remmina-gnome.desktop");
     filePathList.removeAll("/usr/share/applications/ukwm.desktop");
     filePathList.removeAll("/usr/share/applications/nm-applet.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-home.desktop");
     filePathList.removeAll("/usr/share/applications/mate-user-guide.desktop");
     filePathList.removeAll("/usr/share/applications/nm-connection-editor.desktop");
     filePathList.removeAll("/usr/share/applications/pavucontrol-qt.desktop");
@@ -203,7 +201,13 @@ QStringList UkuiMenuInterface::getDesktopFilePath()
     filePathList.removeAll("/usr/share/applications/vim.desktop");
     filePathList.removeAll("/usr/share/applications/kwalletmanager5-kwalletd.desktop");
     filePathList.removeAll("/usr/share/applications/org.gnome.DejaDup.desktop");
-
+    filePathList.removeAll("/usr/share/applications/redshift.desktop");
+    filePathList.removeAll("/usr/share/applications/python3.8.desktop");
+    filePathList.removeAll("/usr/share/applications/yelp.desktop");
+    filePathList.removeAll("/usr/share/applications/peony-computer.desktop");
+    filePathList.removeAll("/usr/share/applications/peony-home.desktop");
+    filePathList.removeAll("/usr/share/applications/peony-trash.desktop");
+    filePathList.removeAll("/usr/share/applications/peony.desktop");
     return filePathList;
 }
 
@@ -269,21 +273,24 @@ QString UkuiMenuInterface::getAppName(QString desktopfp)
     char* filepath=fpbyte.data();
     g_key_file_load_from_file(keyfile,filepath,flags,error);
 
-    QString namestr;
-    QLocale cn;
-    QString language=cn.languageToString(cn.language());
-    if(QString::compare(language,"Chinese")==0)
-    {
-        char* name;
-        name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name[zh_CN]", nullptr, nullptr);
-        if(QString::fromLocal8Bit(name).isEmpty())
-            name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
-        namestr=QString::fromLocal8Bit(name);
-    }
-    else {
-        char* name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
-        namestr=QString::fromLocal8Bit(name);
-    }
+    char* name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
+    QString namestr=QString::fromLocal8Bit(name);
+
+//    QString namestr;
+//    QLocale cn;
+//    QString language=cn.languageToString(cn.language());
+//    if(QString::compare(language,"Chinese")==0)
+//    {
+//        char* name;
+//        name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name[zh_CN]", nullptr, nullptr);
+//        if(QString::fromLocal8Bit(name).isEmpty())
+//            name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
+//        namestr=QString::fromLocal8Bit(name);
+//    }
+//    else {
+//        char* name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
+//        namestr=QString::fromLocal8Bit(name);
+//    }
 
     g_key_file_free(keyfile);
     return namestr;
@@ -602,7 +609,7 @@ QVector<QStringList> UkuiMenuInterface::getFunctionalClassification()
     QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
     setting=new QSettings(path,QSettings::IniFormat);
     setting->beginGroup("recentapp");
-    QStringList keys=setting->childKeys();
+    QStringList keys=setting->allKeys();
     for(int i=0;i<keys.count();i++)
     {
         QString desktopfp=QString("/usr/share/applications/"+keys.at(i));
