@@ -118,7 +118,7 @@ void FullLetterWidget::fillAppList()
                 letterstr="#";
             letterbtnlist.append(letterstr);//存储分类字符
             //插入字母分类按钮
-            PushButton* letterbtn=new PushButton(letterstr,scrollarea->width()-12,20);
+            PushButton* letterbtn=new PushButton(this,letterstr,scrollarea->width()-12,20);
 //            letterbtn->setFixedSize(scrollarea->width(),20);
             scrollareawidLayout->addWidget(letterbtn);
 
@@ -135,11 +135,10 @@ void FullLetterWidget::fillAppList()
             listview->addData(data);
 
             connect(listview,SIGNAL(sendItemClickedSignal(QString)),this,SLOT(execApplication(QString)));
-            connect(listview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+            connect(listview,SIGNAL(sendFixedOrUnfixedSignal(QString,int)),this,SIGNAL(sendUpdateAppListSignal(QString,int)));
             connect(listview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
         }
     }
-
         resizeScrollAreaControls();
 }
 
@@ -148,7 +147,6 @@ void FullLetterWidget::fillAppList()
  */
 void FullLetterWidget::execApplication(QString appname)
 {
-    qDebug()<<appname;
     Q_EMIT sendHideMainWindowSignal();
     QString execpath=pUkuiMenuInterface->getAppExec(pUkuiMenuInterface->getDesktopPathByAppName(appname));
     //移除启动参数%u或者%U
@@ -167,58 +165,30 @@ void FullLetterWidget::execApplication(QString appname)
 void FullLetterWidget::updateAppListView()
 {
     //刷新应用列表界面
-    for(int index=scrollareawidLayout->count()-1;index>=0;index--)
-    {
-            QLayoutItem* item=scrollareawidLayout->takeAt(index);
-            QWidget* wid=item->widget();
-            scrollareawidLayout->removeWidget(wid);
-            wid->setParent(nullptr);
-            delete wid;
-    }
-
-    fillAppList();
+    QLayoutItem *child;
+     while ((child = scrollareawidLayout->takeAt(0)) != 0) {
+         QWidget* wid=child->widget();
+         scrollareawidLayout->removeWidget(wid);
+         wid->setParent(nullptr);
+         delete wid;
+         delete child;
+     }
+     fillAppList();
 
     //刷新字母列表界面
     Q_FOREACH (QAbstractButton* button, buttonList) {
         pBtnGroup->removeButton(button);
     }
     buttonList.clear();
-
-    for(int index=letterlistscrollareawidLayout->count()-1;index>=0;index--)
-    {
-        QLayoutItem* item=letterlistscrollareawidLayout->takeAt(index);
-        QWidget* wid=item->widget();
+    while ((child = letterlistscrollareawidLayout->takeAt(0)) != 0) {
+        QWidget* wid=child->widget();
         letterlistscrollareawidLayout->removeWidget(wid);
         wid->setParent(nullptr);
         delete wid;
-    }
-    char btnstyle[500];
-    sprintf(btnstyle,"QToolButton{background:transparent;color:#8b8b8b;font-size:14px;padding-left:0px;}\
-            QToolButton:hover{background-color:%s;color:#ffffff;font-size:14px;}\
-            QToolButton:pressed{background-color:%s;color:#8b8b8b;font-size:14px;}\
-            QToolButton:checked{background:transparent;color:#ffffff;font-size:14px;}",
-            ClassifyBtnHoverBackground,ClassifyBtnHoverBackground);
-
-    QStringList letterbtnlist=this->letterbtnlist;
-    if(letterbtnlist.contains("&"))
-        letterbtnlist.replace(letterbtnlist.indexOf("&"),"&&");
-    for(int i=0;i<letterbtnlist.size();i++)
-    {
-        QToolButton* letterbtn=new QToolButton;
-        letterbtn->setText(letterbtnlist.at(i));
-        letterbtn->setStyleSheet(btnstyle);
-        letterbtn->setFixedSize(48,48);
-        letterbtn->setCheckable(true);
-        buttonList.append(letterbtn);
-        letterlistscrollareawidLayout->addWidget(letterbtn);
-    }
-    int id=0;
-    Q_FOREACH (QAbstractButton* btn, buttonList) {
-        pBtnGroup->addButton(btn,id++);
+        delete child;
     }
 
-    letterlistscrollarea->widget()->adjustSize();
-    pBtnGroup->button(0)->click();
+    initLetterListScrollArea();
 }
 
 /**
@@ -231,11 +201,6 @@ void FullLetterWidget::resizeScrollAreaControls()
     int row=0;
     while(row<scrollareawidLayout->count()/2)
     {
-        //分类按钮
-//        QLayoutItem* letterbtnwidItem=scrollareawidLayout->itemAt(row*2);
-//        QWidget* letterbtnwid=letterbtnwidItem->widget();
-//        QPushButton* letterbtn=qobject_cast<QPushButton*>(letterbtnwid);
-//        letterbtn->setFixedSize(scrollarea->width()-32,20);
         //应用界面
         QLayoutItem* widItem=scrollareawidLayout->itemAt(row*2+1);
         QWidget* wid=widItem->widget();
@@ -254,7 +219,6 @@ void FullLetterWidget::resizeScrollAreaControls()
 
         }
 
-//        listview->setFixedSize(scrollarea->width()-12,listview->gridSize().height()*rowcount);
         listview->setFixedSize(scrollarea->width()-Style::SliderSize+1,listview->gridSize().height()*rowcount);
         if(row<scrollareawidLayout->count()/2-1)
         {
@@ -271,9 +235,6 @@ void FullLetterWidget::resizeScrollAreaControls()
  */
 void FullLetterWidget::initLetterListWidget()
 {
-    letterlistleftSpacer=new QSpacerItem(40,20,QSizePolicy::Expanding,QSizePolicy::Fixed);
-    letterlistrightSpacer=new QSpacerItem(40,20,QSizePolicy::Expanding,QSizePolicy::Fixed);
-
     letterlistLayout=new QHBoxLayout(letterlistWid);
     letterlistLayout->setContentsMargins(Style::LeftMargin,0,Style::RightMargin,0);
     letterlistLayout->setSpacing(0);
@@ -307,20 +268,20 @@ void FullLetterWidget::initLetterListScrollArea()
             QToolButton:checked{background:transparent;color:#ffffff;border-radius:2px;}",
             ClassifyBtnHoverBackground,ClassifyBtnHoverBackground);
 
-    QFont font;
-    font.setPixelSize(Style::LeftFontSize);
+//    QFont font;
+//    font.setPixelSize(Style::LeftFontSize);
 
     QStringList letterbtnlist=this->letterbtnlist;
     if(letterbtnlist.contains("&"))
         letterbtnlist.replace(letterbtnlist.indexOf("&"),"&&");
     for(int i=0;i<letterbtnlist.size();i++)
     {
-        QToolButton* letterbtn=new QToolButton;
+        QToolButton* letterbtn=new QToolButton(letterlistscrollareaWid);
         letterbtn->setText(letterbtnlist.at(i));
         letterbtn->setStyleSheet(btnstyle);
         letterbtn->setFixedSize(Style::LeftBtnHeight,Style::LeftBtnHeight);
         letterbtn->setCheckable(true);
-        letterbtn->setFont(font);
+//        letterbtn->setFont(font);
         buttonList.append(letterbtn);
         letterlistscrollareawidLayout->addWidget(letterbtn);
 //        connect(letterbtn,SIGNAL(clicked()),this,SLOT(letterBtnClickedSlot()));
@@ -350,8 +311,8 @@ void FullLetterWidget::btnGroupClickedSlot(QAbstractButton *btn)
             {
                 beginPos=scrollarea->verticalScrollBar()->sliderPosition();
                 endPos=letterbtnrowlist.at(num).toInt();
+                scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
                 timer->start(1);
-//                scrollarea->verticalScrollBar()->setSliderPosition(pos);
             }
         }
         else{
@@ -362,25 +323,29 @@ void FullLetterWidget::btnGroupClickedSlot(QAbstractButton *btn)
 
 void FullLetterWidget::timeOutSlot()
 {
+    int speed=0;
+    if(qAbs(endPos-scrollarea->verticalScrollBar()->sliderPosition())<=300)
+        speed=sqrt(qAbs(endPos-scrollarea->verticalScrollBar()->sliderPosition()));
+    else
+    {
+        int height=QApplication::primaryScreen()->geometry().height();
+        speed=height*170/1080;
+    }
 
     if(beginPos<endPos)
     {
-        if(endPos-scrollarea->verticalScrollBar()->sliderPosition()<50)
-            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
-        else
-            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()+50);
+
+        scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()+speed);
     }
     else
     {
-        if(scrollarea->verticalScrollBar()->sliderPosition()-endPos<50)
-            scrollarea->verticalScrollBar()->setSliderPosition(endPos);
-        else
-            scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()-50);
+        scrollarea->verticalScrollBar()->setSliderPosition(scrollarea->verticalScrollBar()->sliderPosition()-speed);
     }
     if(scrollarea->verticalScrollBar()->sliderPosition()==endPos ||
             scrollarea->verticalScrollBar()->sliderPosition()>=scrollarea->verticalScrollBar()->maximum())
     {
         timer->stop();
+        scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
         connect(scrollarea->verticalScrollBar(),SIGNAL(valueChanged(int)),
                 this,SLOT(valueChangedSlot(int)));
     }
@@ -400,13 +365,13 @@ void FullLetterWidget::valueChangedSlot(int value)
         else
             count++;
     }
-    if(count==letterbtnrowlist.count()-1 ||
-            scrollarea->verticalScrollBar()->sliderPosition()==scrollarea->verticalScrollBar()->maximum())
-    {
-        buttonList.at(letterbtnrowlist.count()-1)->setChecked(true);
-        letterlistscrollarea->verticalScrollBar()->setSliderPosition(letterlistscrollarea->verticalScrollBar()->maximum());
+//    if(count==letterbtnrowlist.count()-1 ||
+//            scrollarea->verticalScrollBar()->sliderPosition()==scrollarea->verticalScrollBar()->maximum())
+//    {
+//        buttonList.at(letterbtnrowlist.count()-1)->setChecked(true);
+//        letterlistscrollarea->verticalScrollBar()->setSliderPosition(letterlistscrollarea->verticalScrollBar()->maximum());
 
-    }
+//    }
 
     //向下滚动
     if((buttonList.at(count)->pos().y()+buttonList.at(count)->height()+letterlistscrollarea->widget()->pos().y()) >= letterlistscrollarea->height())
@@ -437,4 +402,5 @@ void FullLetterWidget::widgetMakeZero()
             break;
         }
     }
+    scrollarea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 }
