@@ -82,14 +82,14 @@ private:
     //字母列表界面
     QWidget* letterlistWid=nullptr;
     QHBoxLayout* letterlistLayout=nullptr;
-    QSpacerItem* letterlistleftSpacer=nullptr;
-    QSpacerItem* letterlistrightSpacer=nullptr;
 
     ClassifyScrollArea* letterlistscrollarea=nullptr;
     QWidget* letterlistscrollareaWid=nullptr;
     QVBoxLayout* letterlistscrollareawidLayout=nullptr;
     QList<QAbstractButton*> buttonList;
     QButtonGroup* pBtnGroup=nullptr;
+    QSpacerItem* pLetterListTopSpacer=nullptr;
+    QSpacerItem* pLetterListBottomSpacer=nullptr;
 
     //计时器
     QTimer* timer=nullptr;
@@ -114,7 +114,7 @@ private Q_SLOTS:
     void valueChangedSlot(int value);//滑动条滚动槽函数
 
 Q_SIGNALS:
-    void sendUpdateAppListSignal();//向常用软件模块发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向常用软件模块发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
 };
 
