@@ -87,7 +87,7 @@ void LetterWidget::initAppListWidget()
     mainLayout->addWidget(applistview);
     fillAppListView();
     connect(applistview,SIGNAL(sendItemClickedSignal(QStringList)),this,SLOT(recvItemClickedSlot(QStringList)));
-    connect(applistview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+    connect(applistview,SIGNAL(sendFixedOrUnfixedSignal(QString,int)),this,SIGNAL(sendUpdateAppListSignal(QString,int)));
     connect(applistview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
 
 }
@@ -125,8 +125,6 @@ void LetterWidget::fillAppListView()
         }
     }
 
-    m_delegate= new ItemDelegate(this,1);
-    applistview->setItemDelegate(m_delegate);
     applistview->addData(data);
 }
 
@@ -187,8 +185,6 @@ void LetterWidget::updateAppListView()
             {
                 QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appList.at(i));
                 data.append(QStringList()<<desktopfp<<"1");
-
-                qDebug()<<"图片："<<pUkuiMenuInterface->getAppIcon(desktopfp);
             }
             row+=(appList.count()+1);
 
