@@ -52,7 +52,6 @@ private:
     QLabel* line=nullptr;
     ListView* applistview=nullptr;
     QVector<QStringList> data;
-    ItemDelegate* m_delegate=nullptr;
 
     QStringList letterbtnlist;//存放字母按钮
     QStringList letterbtnrowlist;//存放字母按钮所在行
@@ -75,10 +74,8 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void sendLetterBtnList(QStringList list);//向LetterButtonWidget发送字母按钮列表
-    void sendUpdateAppListSignal();//向常用软件模块发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向常用软件模块发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
-
-
 };
 
 #endif // LETTERWIDGET_H
