@@ -21,6 +21,7 @@
 #include "src/Style/style.h"
 #include <QSvgRenderer>
 #include <QPainter>
+#include <libbamf/bamf-matcher.h>
 #include <QDebug>
 
 MainViewWidget::MainViewWidget(QWidget *parent) :
@@ -81,24 +82,28 @@ void MainViewWidget::initWidget()
     pUkuiMenuInterface=new UkuiMenuInterface;
 
     //进程开启，刷新常用软件界面
-    connect(this,SIGNAL(viewOpenedSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(this,SIGNAL(viewOpenedSignal()),commonusewid,SLOT(updateListViewSlot()));
+    connect(this,SIGNAL(viewOpenedSignal()),fullcommonusewid,SLOT(updateListViewAllSlot()));
+    connect(this,SIGNAL(viewOpenedSignal()),commonusewid,SLOT(updateListViewAllSlot()));
 
     //常用软件界面删除操作，刷新界面
-    connect(commonusewid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(fullcommonusewid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
+    connect(commonusewid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullcommonusewid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(commonusewid,SIGNAL(removeListItemSignal(QString)),fullcommonusewid,SLOT(removeListItemSlot(QString)));
+    connect(fullcommonusewid,SIGNAL(removeListItemSignal(QString)),commonusewid,SLOT(removeListItemSlot(QString)));
+    connect(commonusewid,SIGNAL(removeListAllItemSignal()),fullcommonusewid,SLOT(removeListAllItemSlot()));
+    connect(fullcommonusewid,SIGNAL(removeListAllItemSignal()),commonusewid,SLOT(removeListAllItemSlot()));
 
     //字母排序、功能分类界面、搜索界面固定或取消固定到常用软件，刷新常用软件界面
-    connect(letterwid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(fullletterwid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(functionwid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(fullfunctionwid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(letterwid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(fullletterwid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(functionwid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(fullfunctionwid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
-    connect(searchresultwid,SIGNAL(sendUpdateAppListSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(fullsearchresultwid,SIGNAL(sendUpdateAppListSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
+    connect(letterwid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullletterwid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(functionwid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullfunctionwid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(letterwid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullletterwid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(functionwid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullfunctionwid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(searchresultwid,SIGNAL(sendUpdateAppListSignal(QString,int)),commonusewid,SLOT(updateListViewSlot(QString,int)));
+    connect(fullsearchresultwid,SIGNAL(sendUpdateAppListSignal(QString,int)),fullcommonusewid,SLOT(updateListViewSlot(QString,int)));
 
     //监控.desktop文件目录
     fileWatcher=new QFileSystemWatcher(this);
@@ -108,8 +113,8 @@ void MainViewWidget::initWidget()
     connect(this,SIGNAL(directoryChangedSignal()),fullletterwid,SLOT(updateAppListView()));
     connect(this,SIGNAL(directoryChangedSignal()),functionwid,SLOT(updateAppListView()));
     connect(this,SIGNAL(directoryChangedSignal()),fullfunctionwid,SLOT(updateAppListView()));
-    connect(this,SIGNAL(directoryChangedSignal()),commonusewid,SLOT(updateListViewSlot()));
-    connect(this,SIGNAL(directoryChangedSignal()),fullcommonusewid,SLOT(updateListViewSlot()));
+    connect(this,SIGNAL(directoryChangedSignal()),commonusewid,SLOT(updateListViewAllSlot()));
+    connect(this,SIGNAL(directoryChangedSignal()),fullcommonusewid,SLOT(updateListViewAllSlot()));
 
     //发送隐藏主界面信号
     connect(commonusewid,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
@@ -126,6 +131,7 @@ void MainViewWidget::initWidget()
     loadLetterWidget();
 
     //监控应用进程开启
+    bamf_matcher_get_default();
     QDBusConnection::sessionBus().connect("org.ayatana.bamf","/org/ayatana/bamf/matcher","org.ayatana.bamf.matcher",
                                          QString("ViewOpened"),this,SLOT(ViewOpenedSlot(QDBusMessage)));
 
@@ -178,10 +184,10 @@ void MainViewWidget::initQueryLineEdit()
     pQueryIcon->setStyleSheet("background:transparent");
     pQueryIcon->setFixedSize(pixmap->size());
     pQueryIcon->setPixmap(*pixmap);
-    QFont font;
-    font.setPixelSize(Style::QueryLineEditFontSize);
+//    QFont font;
+//    font.setPixelSize(Style::QueryLineEditFontSize);
     pQueryText=new QLabel(pIconTextWid);
-    pQueryText->setFont(font);
+//    pQueryText->setFont(font);
     pQueryText->setText(tr("Search"));
     pQueryText->setStyleSheet("background:transparent;color:#626c6e;");
     pQueryText->adjustSize();
@@ -192,6 +198,7 @@ void MainViewWidget::initQueryLineEdit()
     queryLayout->setAlignment(pIconTextWid,Qt::AlignCenter);
     querylineEdit->setFocusPolicy(Qt::ClickFocus);
     querylineEdit->installEventFilter(this);
+    querylineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 
     searchappthread=new SearchAppThread;
     connect(this,SIGNAL(sendSearchKeyword(QString)),
@@ -203,6 +210,8 @@ void MainViewWidget::initQueryLineEdit()
 
 bool MainViewWidget::eventFilter(QObject *watched, QEvent *event)
 {
+//    QFont font;
+//    font.setPixelSize(Style::QueryLineEditFontSize);
     if(watched==querylineEdit)
     {
         if(event->type()==QEvent::FocusIn)
@@ -213,22 +222,32 @@ bool MainViewWidget::eventFilter(QObject *watched, QEvent *event)
             queryLayout->setAlignment(pIconTextWid,Qt::AlignLeft);
 
              char style[200];
-             sprintf(style, "QLineEdit{border:1px solid %s;background-color:%s;border-radius:2px;font-size:14px;color:#ffffff;}",
+             sprintf(style, "QLineEdit{border:1px solid %s;background-color:%s;border-radius:2px;color:#ffffff;}",
                      QueryLineEditClickedBorder,QueryLineEditClickedBackground);
              querylineEdit->setStyleSheet(style);
              querylineEdit->setTextMargins(20,1,0,1);
+//             querylineEdit->setFont(font);
              if(!querylineEdit->text().isEmpty())
                  searchAppSlot(querylineEdit->text());
         }
         else if(event->type()==QEvent::FocusOut)
         {
-             char style[100];
-             sprintf(style, "QLineEdit{border:0px;background-color:%s;border-radius:2px;}",QueryLineEditBackground);
-             querylineEdit->setStyleSheet(style);
-             querylineEdit->setTextMargins(0,1,0,1);
-             pIconTextWidLayout->addWidget(pQueryText);
-             pIconTextWid->setFixedSize(pQueryIcon->width()+pQueryText->width()+10,Style::QueryLineEditHeight);
-             queryLayout->setAlignment(pIconTextWid,Qt::AlignCenter);
+            if(querylineEdit->text().isEmpty())
+            {
+                char style[100];
+                sprintf(style, "QLineEdit{border:0px;background-color:%s;border-radius:2px;}",QueryLineEditBackground);
+                querylineEdit->setStyleSheet(style);
+                querylineEdit->setTextMargins(0,1,0,1);
+                pIconTextWidLayout->addWidget(pQueryText);
+                pIconTextWid->setFixedSize(pQueryIcon->width()+pQueryText->width()+10,Style::QueryLineEditHeight);
+                queryLayout->setAlignment(pIconTextWid,Qt::AlignCenter);
+            }
+            else {
+                char style[100];
+                sprintf(style, "QLineEdit{border:0px;background-color:%s;border-radius:2px;color:#ffffff;}",
+                        QueryLineEditBackground);
+                querylineEdit->setStyleSheet(style);
+            }
         }
     }
 
@@ -327,7 +346,6 @@ void MainViewWidget::loadMinMainView()
     topLayout->setAlignment(querylineEdit,Qt::AlignCenter);
     querylineEdit->setFixedSize(288,30);
 
-    is_fullWid=false;
     if(widgetState==0)
     {
         QLayoutItem* child;
@@ -348,6 +366,7 @@ void MainViewWidget::loadMinMainView()
         loadLetterWidget();
     else
         loadFunctionWidget();
+    is_fullWid=false;
 }
 
 /**
@@ -364,7 +383,6 @@ void MainViewWidget::loadMaxMainView()
                                   0,
                                   (topWidget->width()-Style::LeftWidWidth-querylineEdit->width())/2,
                                   0);
-    is_fullWid=true;
     if(widgetState==0)
     {
         QLayoutItem* child;
@@ -385,6 +403,7 @@ void MainViewWidget::loadMaxMainView()
         loadFullLetterWidget();
     else if(widgetState==3)
         loadFullFunctionWidget();
+    is_fullWid=true;
 }
 
 /**
@@ -392,6 +411,11 @@ void MainViewWidget::loadMaxMainView()
  */
 void MainViewWidget::loadCommonUseWidget()
 {
+    fullcommonusewid->widgetMakeZero();
+    letterwid->widgetMakeZero();
+    fullletterwid->widgetMakeZero();
+    functionwid->widgetMakeZero();
+    fullfunctionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -402,7 +426,6 @@ void MainViewWidget::loadCommonUseWidget()
         }
 
     }
-    commonusewid->widgetMakeZero();
     mainLayout->addWidget(commonusewid);
     widgetState=1;
     saveCurrentWidState=1;
@@ -413,6 +436,11 @@ void MainViewWidget::loadCommonUseWidget()
  */
 void MainViewWidget::loadLetterWidget()
 {
+    commonusewid->widgetMakeZero();
+    fullcommonusewid->widgetMakeZero();
+    fullletterwid->widgetMakeZero();
+    functionwid->widgetMakeZero();
+    fullfunctionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -423,7 +451,6 @@ void MainViewWidget::loadLetterWidget()
         }
 
     }
-    letterwid->widgetMakeZero();
     mainLayout->addWidget(letterwid);
     widgetState=2;
     saveCurrentWidState=2;
@@ -434,6 +461,11 @@ void MainViewWidget::loadLetterWidget()
  */
 void MainViewWidget::loadFunctionWidget()
 {
+    commonusewid->widgetMakeZero();
+    fullcommonusewid->widgetMakeZero();
+    letterwid->widgetMakeZero();
+    fullletterwid->widgetMakeZero();
+    fullfunctionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -444,7 +476,6 @@ void MainViewWidget::loadFunctionWidget()
         }
 
     }
-    functionwid->widgetMakeZero();
     mainLayout->addWidget(functionwid);
     widgetState=3;
     saveCurrentWidState=3;
@@ -456,6 +487,11 @@ void MainViewWidget::loadFunctionWidget()
  */
 void MainViewWidget::loadFullCommonUseWidget()
 {
+    commonusewid->widgetMakeZero();
+    letterwid->widgetMakeZero();
+    fullletterwid->widgetMakeZero();
+    functionwid->widgetMakeZero();
+    fullfunctionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -466,7 +502,6 @@ void MainViewWidget::loadFullCommonUseWidget()
         }
 
     }
-    fullcommonusewid->widgetMakeZero();
     mainLayout->addWidget(fullcommonusewid);
     widgetState=1;
     saveCurrentWidState=1;
@@ -477,6 +512,11 @@ void MainViewWidget::loadFullCommonUseWidget()
  */
 void MainViewWidget::loadFullLetterWidget()
 {
+    commonusewid->widgetMakeZero();
+    fullcommonusewid->widgetMakeZero();
+    letterwid->widgetMakeZero();
+    functionwid->widgetMakeZero();
+    fullfunctionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -486,7 +526,6 @@ void MainViewWidget::loadFullLetterWidget()
             childwid->setParent(nullptr);
         }
     }
-    fullletterwid->widgetMakeZero();
     mainLayout->addWidget(fullletterwid);
     widgetState=2;
     saveCurrentWidState=2;
@@ -497,6 +536,11 @@ void MainViewWidget::loadFullLetterWidget()
  */
 void MainViewWidget::loadFullFunctionWidget()
 {
+    commonusewid->widgetMakeZero();
+    fullcommonusewid->widgetMakeZero();
+    letterwid->widgetMakeZero();
+    fullletterwid->widgetMakeZero();
+    functionwid->widgetMakeZero();
     QLayoutItem *child;
     if((child = mainLayout->takeAt(1)) != nullptr) {
         QWidget* childwid=child->widget();
@@ -507,7 +551,6 @@ void MainViewWidget::loadFullFunctionWidget()
         }
 
     }
-    fullfunctionwid->widgetMakeZero();
     mainLayout->addWidget(fullfunctionwid);
     widgetState=3;
     saveCurrentWidState=3;
@@ -526,37 +569,39 @@ void MainViewWidget::ViewOpenedSlot(QDBusMessage msg)
                                 "org.ayatana.bamf.application",QDBusConnection::sessionBus());
         QDBusReply<QString> replyapp =ifaceapp.call("DesktopFile");
         QString desktopfp=replyapp.value();
-        QFileInfo fileInfo(desktopfp);
-        QString desktopfn=fileInfo.fileName();
-
-        QString dateTimeKey;
-        dateTimeKey.clear();
-        if(!desktopfp.isEmpty())
+        QStringList desktopfpList=pUkuiMenuInterface->getDesktopFilePath();
+        if(desktopfpList.contains(desktopfp))
         {
-            setting->beginGroup("application");
-            if(!setting->contains(desktopfn))
-            {
-                setting->setValue(desktopfn,1);
-                setting->sync();
-            }
-            else if(setting->value(desktopfn).toInt()==1)
-            {
-                setting->setValue(desktopfn,2);
-                setting->sync();
-                dateTimeKey=desktopfn;
-                Q_EMIT viewOpenedSignal();
-            }
-            setting->endGroup();
-        }
+            QFileInfo fileInfo(desktopfp);
+            QString desktopfn=fileInfo.fileName();
 
-        if(!dateTimeKey.isEmpty())
-        {
-            QDateTime dt=QDateTime::currentDateTime();
-            int datetime=dt.toTime_t();
-            setting->beginGroup("datetime");
-            setting->setValue(dateTimeKey,datetime);
-            setting->sync();
-            setting->endGroup();
+            QString dateTimeKey;
+            dateTimeKey.clear();
+            if(!desktopfn.isEmpty())
+            {
+                setting->beginGroup("lockapplication");
+                bool ret=setting->contains(desktopfn);
+                setting->endGroup();
+                if(!ret)
+                {
+                    setting->beginGroup("application");
+                    setting->setValue(desktopfn,setting->value(desktopfn).toInt()+1);
+                    dateTimeKey=desktopfn;
+                    Q_EMIT viewOpenedSignal();
+                    setting->sync();
+                    setting->endGroup();
+                }
+            }
+
+            if(!dateTimeKey.isEmpty())
+            {
+                QDateTime dt=QDateTime::currentDateTime();
+                int datetime=dt.toTime_t();
+                setting->beginGroup("datetime");
+                setting->setValue(dateTimeKey,datetime);
+                setting->sync();
+                setting->endGroup();
+            }
         }
     }
 }
@@ -581,7 +626,8 @@ void MainViewWidget::directoryChangedSlot()
                 QFileInfo fileInfo(desktopfpList.at(i));
                 QString desktopfn=fileInfo.fileName();
                 setting->setValue(desktopfn,datetime);
-                qDebug()<<"anzhuang:"<<desktopfn;
+                qDebug()<<"安装:"<<desktopfn;
+                break;
             }
 
         }
@@ -596,11 +642,13 @@ void MainViewWidget::directoryChangedSlot()
         {
             if(!desktopfpList.contains(UkuiMenuInterface::desktopfpVector.at(i)))
             {
-//                QString appname=pUkuiMenuInterface->getAppName(UkuiMenuInterface::desktopfpVector.at(i));
-//                QString appname=UkuiMenuInterface::appInfoVector.at(i).at(2);
                 QString desktopfp=UkuiMenuInterface::appInfoVector.at(i).at(0);
                 QFileInfo fileInfo(desktopfp);
                 QString desktopfn=fileInfo.fileName();
+                setting->beginGroup("lockapplication");
+                setting->remove(desktopfn);
+                setting->sync();
+                setting->endGroup();
                 setting->beginGroup("application");
                 setting->remove(desktopfn);
                 setting->sync();
@@ -613,7 +661,8 @@ void MainViewWidget::directoryChangedSlot()
                 setting->remove(desktopfn);
                 setting->sync();
                 setting->endGroup();
-                qDebug()<<"xiezai:"<<desktopfn;
+                qDebug()<<"卸载:"<<desktopfn;
+                break;
             }
         }
         UkuiMenuInterface::appInfoVector=pUkuiMenuInterface->create_appinfo_vector();
