@@ -44,7 +44,7 @@ MainWindow::MainWindow(QWidget *parent) :
     timeOutKeys.clear();
     for(int i=0;i<dateTimeKeys.count();i++)
     {
-        if((currentDateTime-setting->value(dateTimeKeys.at(i)).toInt())/nDaySec >= 7)
+        if((currentDateTime-setting->value(dateTimeKeys.at(i)).toInt())/nDaySec >= 4)
         {
             timeOutKeys.append(dateTimeKeys.at(i));
         }
@@ -67,29 +67,13 @@ MainWindow::MainWindow(QWidget *parent) :
     QStringList recentAppKeys=setting->allKeys();
     for(int i=0;i<recentAppKeys.count();i++)
     {
-        if((currentDateTime-setting->value(recentAppKeys.at(i)).toInt())/nDaySec >= 7)
+        if((currentDateTime-setting->value(recentAppKeys.at(i)).toInt())/nDaySec >= 3)
             setting->remove(recentAppKeys.at(i));
     }
     setting->sync();
     setting->endGroup();
 
     initMainWindow();
-
-//    pEnterAnimation=new QPropertyAnimation;
-//    pEnterAnimation->setTargetObject(this);
-//    pEnterAnimation->setPropertyName("size");
-//    pEnterAnimation->setDuration(500);
-//    pEnterAnimation->setStartValue(QSize(390,532));
-//    pEnterAnimation->setEndValue(QSize(490,532));
-//    pEnterAnimation->setEasingCurve(QEasingCurve::Linear);
-
-//    pLeaveAnimation=new QPropertyAnimation;
-//    pLeaveAnimation->setTargetObject(this);
-//    pLeaveAnimation->setPropertyName("size");
-//    pLeaveAnimation->setDuration(500);
-//    pLeaveAnimation->setStartValue(QSize(490,532));
-//    pLeaveAnimation->setEndValue(QSize(390,532));
-//    pLeaveAnimation->setEasingCurve(QEasingCurve::Linear);
 }
 
 MainWindow::~MainWindow()
@@ -101,7 +85,8 @@ MainWindow::~MainWindow()
 void MainWindow::initMainWindow()
 {
 //    this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::SplashScreen);
-    this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::Popup);
+//    this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::Popup);
+    this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
 //    this->setStyleSheet("background:transparent;");
 //    char style[100];
 //    sprintf(style, "border:0px;background-color:%s;",DefaultBackground);
@@ -111,9 +96,14 @@ void MainWindow::initMainWindow()
     this->setAutoFillBackground(false);
     this->setFocusPolicy(Qt::StrongFocus);
 
-    ui->mainToolBar->hide();
-    ui->menuBar->hide();
-    ui->statusBar->hide();
+//    QPainterPath path;
+//    auto rect = this->rect();
+//    rect.adjust(1, 1, -1, -1);
+//    path.addRoundedRect(rect, 6, 6);
+//    setProperty("blurRegion", QRegion(path.toFillPolygon().toPolygon()));
+
+    ui->menubar->hide();
+    ui->statusbar->hide();
     this->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
 //    this->setMinimumSize(390+20+2,532+20+2);
 //    this->setContentsMargins(1,21,21,1);
@@ -141,11 +131,18 @@ void MainWindow::initMainWindow()
     mainlayout->setContentsMargins(0,0,0,0);
     mainlayout->setSpacing(0);
     centralWidget()->setLayout(mainlayout);
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    QGSettings* gsetting=nullptr;
+    if(fileInfo.exists())
+    {
+        gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+    }
+    else
+    {
+        position=0;
+    }
     char style[100];
     if(position==0)
         sprintf(style, "border:0px;background-color:%s;border-top-right-radius:6px;",DefaultBackground);
@@ -171,16 +168,22 @@ void MainWindow::initMainWindow()
     connect(mainviewwid,SIGNAL(sendHideMainWindowSignal()),this,SLOT(recvHideMainWindowSlot()));
     connect(sidebarwid,SIGNAL(sendHideMainWindowSignal()),this,SLOT(recvHideMainWindowSlot()));
 
-    connect(QApplication::desktop(),SIGNAL(resized(int)),this,SLOT(monitorResolutionChange(int)));
+    connect(QApplication::primaryScreen(),SIGNAL(geometryChanged(QRect)),
+            this,SLOT(monitorResolutionChange(QRect)));
+    connect(qApp,SIGNAL(primaryScreenChanged(QScreen*)),this,
+            SLOT(primaryScreenChangedSlot(QScreen*)));
+
+    connect(gsetting,SIGNAL(changed(QString)),
+            this,SLOT(panelShangedSlot(QString)));
 }
 
 /**
  * 添加阴影
  */
-void MainWindow::paintEvent(QPaintEvent *)
-{
-    if(!is_fullscreen)
-    {
+//void MainWindow::paintEvent(QPaintEvent *)
+//{
+//    if(!is_fullscreen)
+//    {
 //        QPainter painter(this);
 //        const qreal radius =6;
 
@@ -241,42 +244,40 @@ void MainWindow::paintEvent(QPaintEvent *)
     //        painter.setBrush(Qt::NoBrush);
     //        painter.drawPath(path);
     //    }
-    }
-}
+//    }
+//}
 
 /**
  * 显示全屏窗口
  */
 void MainWindow::showFullScreenWidget()
 {
-////    this->showMaximized();
-//    is_full=true;
-//    classification_widget=arg;
-//    sidebarwid->setVisible(false);
-//    mainviewwid->setVisible(false);
-//    char widgetcolor[100];
-//    sprintf(widgetcolor, "border:0px;background-color:%s;",MAINVIEWWIDGETCOLOR);
-//    mainwidget->setStyleSheet(QString::fromLocal8Bit(widgetcolor));
-//    pAnimation->start();
-
     is_fullscreen=true;
     this->setContentsMargins(0,0,0,0);
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
-
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
-    QDBusReply<int> panelSize=iface.call("GetPanelSize","");
-    if(position==0)
-        this->setGeometry(QRect(0,0,Style::widthavailable,Style::heightavailable));
-    else if(position==1)
-        this->setGeometry(QRect(0,panelSize,Style::widthavailable,Style::heightavailable));
-    else if(position==2)
-        this->setGeometry(QRect(panelSize,0,Style::widthavailable,Style::heightavailable));
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    int panelSize=0;
+    if(fileInfo.exists())
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+        panelSize=gsetting->get("panelsize").toInt();
+    }
     else
-        this->setGeometry(QRect(0,0,Style::widthavailable,Style::heightavailable));
-//    this->setGeometry(QApplication::desktop()->availableGeometry());
+    {
+        position=0;
+        panelSize=46;
+    }
+    int x=QApplication::primaryScreen()->geometry().x();
+    int y=QApplication::primaryScreen()->geometry().y();
+    if(position==0)
+        this->setGeometry(QRect(x,y,Style::widthavailable,Style::heightavailable));
+    else if(position==1)
+        this->setGeometry(QRect(x,panelSize,Style::widthavailable,Style::heightavailable));
+    else if(position==2)
+        this->setGeometry(QRect(panelSize,y,Style::widthavailable,Style::heightavailable));
+    else
+        this->setGeometry(QRect(x,y,Style::widthavailable,Style::heightavailable));
     sidebarwid->loadMaxSidebar();
     mainviewwid->loadMaxMainView();
     //移除分割线
@@ -294,51 +295,50 @@ void MainWindow::showFullScreenWidget()
  */
 void MainWindow::showDefaultWidget()
 {
-////    this->showNormal();
-//    is_full=false;
-//    classification_widget=arg;
-//    sidebarwid->setVisible(false);
-//    mainviewwid->setVisible(false);
-//    char widgetcolor[100];
-//    sprintf(widgetcolor, "border:0px;background-color:%s;",MAINVIEWWIDGETCOLOR);
-//    mainwidget->setStyleSheet(QString::fromLocal8Bit(widgetcolor));
-//    pAnimation->start();
-
     is_fullscreen=false;
     this->setContentsMargins(0,0,0,0);
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
-
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
-    QDBusReply<int> panelSize=iface.call("GetPanelSize","");
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    int panelSize=0;
+    if(fileInfo.exists())
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+        panelSize=gsetting->get("panelsize").toInt();
+    }
+    else
+    {
+        position=0;
+        panelSize=46;
+    }
     char style[100];
+    int x=QApplication::primaryScreen()->geometry().x();
+    int y=QApplication::primaryScreen()->geometry().y();
     if(position==0)
     {
         sprintf(style, "border:0px;background-color:%s;border-top-right-radius:6px;",DefaultBackground);
-        this->setGeometry(QRect(0,Style::heightavailable-590,376,590));
+        this->setGeometry(QRect(x,Style::heightavailable-590,376,590));
     }
     else if(position==1)
     {
         sprintf(style, "border:0px;background-color:%s;border-bottom-right-radius:6px;",DefaultBackground);
-        this->setGeometry(QRect(0,panelSize,376,590));
+        this->setGeometry(QRect(x,panelSize,376,590));
     }
     else if(position==2)
     {
         sprintf(style, "border:0px;background-color:%s;border-bottom-right-radius:6px;",DefaultBackground);
-        this->setGeometry(QRect(panelSize,0,376,590));
+        this->setGeometry(QRect(panelSize,y,376,590));
     }
     else
     {
         sprintf(style, "border:0px;background-color:%s;border-bottom-left-radius:6px;",DefaultBackground);
-        this->setGeometry(QRect(Style::widthavailable-376,0,376,590));
+        this->setGeometry(QRect(Style::widthavailable-376,y,376,590));
     }
     sidebarwid->loadMinSidebar();
     mainviewwid->loadMinMainView();
     //插入分割线
     mainlayout->insertWidget(1,line);
-    this->repaint();
+//    this->repaint();
     frame->setStyleSheet(style);
 }
 
@@ -384,29 +384,40 @@ void MainWindow::mainWindowMakeZero()
     sidebarwid->widgetMakeZero();
 }
 
-//void MainWindow::recv_hover_signal_slot(bool is_hover)
-//{
-//    if(is_hover)
-//        pEnterAnimation->start();
-//    else
-//        pLeaveAnimation->start();
-//}
+void MainWindow::monitorResolutionChange(QRect rect)
+{
+    Q_UNUSED(rect);
+    qApp->quit();
+    QProcess::startDetached(QString("/usr/bin/ukui-menu"));
+}
 
-void MainWindow::monitorResolutionChange(int screen)
+void MainWindow::primaryScreenChangedSlot(QScreen *screen)
 {
     Q_UNUSED(screen);
     qApp->quit();
     QProcess::startDetached(QString("/usr/bin/ukui-menu"));
 }
 
+void MainWindow::panelShangedSlot(QString key)
+{
+    Q_UNUSED(key);
+    qApp->quit();
+    QProcess::startDetached(QString("/usr/bin/ukui-menu"));
+}
+
 void MainWindow::setFrameStyle()
 {
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
-
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    if(fileInfo.exists())
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+    }
+    else
+    {
+        position=0;
+    }
     char style[100];
     if(!is_fullscreen)
     {
@@ -444,5 +455,4 @@ void MainWindow::keyPressEvent(QKeyEvent *e)
             mainviewwid->setLineEditFocus(e->text());
         }
     }
-
 }
