@@ -72,15 +72,16 @@ private:
 protected:
     void initMainWindow();
     bool event(QEvent *event);//鼠标点击窗口外部事件
-    void paintEvent(QPaintEvent*);//添加阴影
+//    void paintEvent(QPaintEvent*);//添加阴影
     void keyPressEvent(QKeyEvent* e);//查询框响应键盘事件
 
 private Q_SLOTS:
     void showFullScreenWidget();//加载全屏窗口
     void showDefaultWidget();//显示默认窗口
     void recvHideMainWindowSlot();//接收隐藏主窗口信号
-//    void recv_hover_signal_slot(bool is_hover);
-    void monitorResolutionChange(int screen);//监控屏幕分辨率
+    void monitorResolutionChange(QRect rect);//监控屏幕分辨率
+    void primaryScreenChangedSlot(QScreen *screen);
+    void panelShangedSlot(QString key);
 };
 
 #endif // MAINWINDOW_H
