@@ -37,10 +37,25 @@ RightClickMenu::RightClickMenu(QWidget *parent):
     OtherListAction=new QWidgetAction(othermenu);
     OtherListWid=new QWidget();
 
+    //关机按钮右键菜单
+    shutdownmenu=new QMenu(this);
+    shutdownmenu->setLayoutDirection(Qt::LeftToRight);
+    shutdownmenu->setFixedSize(250+2,36*5+12+2);
+    LockScreenAction=new QWidgetAction(shutdownmenu);
+    LockScreenWid=new QWidget();
+    SwitchUserAction=new QWidgetAction(shutdownmenu);
+    SwitchUserWid=new QWidget();
+    LogOutAction=new QWidgetAction(shutdownmenu);
+    LogOutWid=new QWidget();
+    RebootAction=new QWidgetAction(shutdownmenu);
+    RebootWid=new QWidget();
+    ShutDownAction=new QWidgetAction(shutdownmenu);
+    ShutDownWid=new QWidget();
+
     //常用应用按钮右键菜单
     cuappbtnmenu=new QMenu(this);
     cuappbtnmenu->setLayoutDirection(Qt::LeftToRight);
-    cuappbtnmenu->setFixedSize(250+2,36*7+4*6+12+2);
+    cuappbtnmenu->setFixedSize(250+2,36*7+4*3+9*3+12+2);
     CuFix2CommonUseAction=new QWidgetAction(cuappbtnmenu);
     CuFix2CommonUseWid=new QWidget();
     CuUnfixed4CommonUseAction=new QWidgetAction(cuappbtnmenu);
@@ -63,7 +78,7 @@ RightClickMenu::RightClickMenu(QWidget *parent):
     //普通应用按钮右键菜单
     appbtnmenu=new QMenu(this);
     appbtnmenu->setLayoutDirection(Qt::LeftToRight);
-    appbtnmenu->setFixedSize(250+2,36*5+4*4+12+2);
+    appbtnmenu->setFixedSize(250+2,36*5+4*2+9*2+12+2);
     Fix2CommonUseAction=new QWidgetAction(appbtnmenu);
     Fix2CommonUseWid=new QWidget();
     Unfixed4CommonUseAction=new QWidgetAction(appbtnmenu);
@@ -91,12 +106,12 @@ RightClickMenu::RightClickMenu(QWidget *parent):
         separatorWid[i].setStyleSheet("background:transparent;");
         QHBoxLayout* layout=new QHBoxLayout(&separatorWid[i]);
         separatorWid[i].setLayout(layout);
-        layout->setContentsMargins(0,0,0,0);
-        separatorWid[i].setFixedSize(246,4);
+        layout->setContentsMargins(8,0,8,0);
+        separatorWid[i].setFixedSize(246,9);
         separatorWid[i].setFocusPolicy(Qt::NoFocus);
-        separatorLabel[i].setFixedSize(separatorWid->width(),1);
+        separatorLabel[i].setFixedSize(separatorWid->width()-16,1);
         layout->addWidget(&separatorLabel[i]);
-        layout->setAlignment(&separatorLabel[i],Qt::AlignVCenter);
+        layout->setAlignment(&separatorLabel[i],Qt::AlignCenter);
     }
 
     separatorAction_1=new QWidgetAction(cuappbtnmenu);
@@ -171,25 +186,24 @@ RightClickMenu::~RightClickMenu()
 //常用应用按钮右键菜单
 void RightClickMenu::addCommonUseAppBtnAction()
 {
-    setting->beginGroup("application");
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
+    setting->beginGroup("lockapplication");
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
-    if(!setting->contains(desktopfn) || setting->value(desktopfn).toInt()>0)
+    if(!setting->contains(desktopfn))
     {
         initWidgetAction(CuFix2CommonUseWid,":/data/img/mainviewwidget/fixed.svg",tr("Pin to common"));
         CuFix2CommonUseAction->setDefaultWidget(CuFix2CommonUseWid);
         cuappbtnmenu->addAction(CuFix2CommonUseAction);
         connect(CuFix2CommonUseAction, SIGNAL(triggered()),this,SLOT(fixToCommonUseActionTriggerSlot()));
     }
-
-    if(setting->contains(desktopfn) && setting->value(desktopfn).toInt()==0)
+    else
     {
         initWidgetAction(CuUnfixed4CommonUseWid,":/data/img/mainviewwidget/unfixed.svg",tr("Unpin from common"));
         CuUnfixed4CommonUseAction->setDefaultWidget(CuUnfixed4CommonUseWid);
         cuappbtnmenu->addAction(CuUnfixed4CommonUseAction);
         connect(CuUnfixed4CommonUseAction, SIGNAL(triggered()),this,SLOT(unfixedFromCommonUseActionTriggerSlot()));
     }
+    setting->endGroup();
 
     cuappbtnmenu->addSeparator();
 
@@ -225,11 +239,13 @@ void RightClickMenu::addCommonUseAppBtnAction()
     cuappbtnmenu->addAction(separatorAction_1);
 //    cuappbtnmenu->addSeparator();
 
+
     initWidgetAction(CuDeleteWid,"",tr("Remove from list"));
     CuDeleteAction->setDefaultWidget(CuDeleteWid);
     cuappbtnmenu->addAction(CuDeleteAction);
     connect(CuDeleteAction,SIGNAL(triggered()),this,SLOT(commonUseDeleteActionTriggerSlot()));
-    if(setting->contains(desktopfn) && setting->value(desktopfn).toInt()==0)
+    setting->beginGroup("lockapplication");
+    if(setting->contains(desktopfn))
     {
         QLayoutItem* item=CuDeleteWid->layout()->itemAt(0);
         QWidget* wid=item->widget();
@@ -237,6 +253,7 @@ void RightClickMenu::addCommonUseAppBtnAction()
         label->setStyleSheet("QLabel{background:transparent;border:0px;color:#4Dffffff;font-size:14px;}");
         CuDeleteAction->setDisabled(true);
     }
+    setting->endGroup();
 
     cuappbtnmenu->addSeparator();
 
@@ -244,14 +261,8 @@ void RightClickMenu::addCommonUseAppBtnAction()
     CuDeleteAllAction->setDefaultWidget(CuDeleteAllWid);
     cuappbtnmenu->addAction(CuDeleteAllAction);
     connect(CuDeleteAllAction,SIGNAL(triggered()),this,SLOT(commonUseDeleteAllActionTriggerSlot()));
-    QStringList keys=setting->childKeys();
-    int count;
-    for(count=0;count<keys.count();count++)
-    {
-        if(setting->value(keys.at(count)).toInt()==2)
-            break;
-    }
-    if(count==keys.count())
+    setting->beginGroup("application");
+    if(setting->allKeys().size()==0)
     {
         QLayoutItem* item=CuDeleteAllWid->layout()->itemAt(0);
         QWidget* wid=item->widget();
@@ -259,19 +270,16 @@ void RightClickMenu::addCommonUseAppBtnAction()
         label->setStyleSheet("QLabel{background:transparent;border:0px;color:#4Dffffff;font-size:14px;}");
         CuDeleteAllAction->setDisabled(true);
     }
+    setting->endGroup();
 
-//    cuappbtnmenu->addSeparator();
     cuappbtnmenu->addAction(separatorAction_2);
-//    cuappbtnmenu->addSeparator();
 
     initWidgetAction(CuUninstallWid,":/data/img/mainviewwidget/uninstall.svg",tr("Uninstall"));
     CuUninstallAction->setDefaultWidget(CuUninstallWid);
     cuappbtnmenu->addAction(CuUninstallAction);
     connect(CuUninstallAction, SIGNAL(triggered()),this,SLOT(uninstallActionTriggerSlot()));
 
-//    cuappbtnmenu->addSeparator();
     cuappbtnmenu->addAction(separatorAction_3);
-//    cuappbtnmenu->addSeparator();
 
     initWidgetAction(CuAttributeWid,":/data/img/mainviewwidget/attributeaction.svg",tr("Attribute"));
     CuAttributeAction->setDefaultWidget(CuAttributeWid);
@@ -281,27 +289,22 @@ void RightClickMenu::addCommonUseAppBtnAction()
     cuappbtnmenu->setAttribute(Qt::WA_TranslucentBackground);
 //    cuappbtnmenu->setWindowOpacity(RightClickMenuOpacity);
     cuappbtnmenu->setStyleSheet(style);
-
-    setting->endGroup();
 }
 
 //普通应用按钮右键菜单
 void RightClickMenu::addAppBtnAction()
 {
-
-    setting->beginGroup("application");
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
+    setting->beginGroup("lockapplication");
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
-    if(!setting->contains(desktopfn) || setting->value(desktopfn).toInt()>0)
+    if(!setting->contains(desktopfn))
     {
         initWidgetAction(Fix2CommonUseWid,":/data/img/mainviewwidget/fixed.svg",tr("Pin to common"));
         Fix2CommonUseAction->setDefaultWidget(Fix2CommonUseWid);
         appbtnmenu->addAction(Fix2CommonUseAction);
         connect(Fix2CommonUseAction, SIGNAL(triggered()),this,SLOT(fixToCommonUseActionTriggerSlot()));
     }
-
-    if(setting->contains(desktopfn) && setting->value(desktopfn).toInt()==0)
+    else
     {
         initWidgetAction(Unfixed4CommonUseWid,":/data/img/mainviewwidget/unfixed.svg",tr("Unpin from common"));
         Unfixed4CommonUseAction->setDefaultWidget(Unfixed4CommonUseWid);
@@ -312,7 +315,6 @@ void RightClickMenu::addAppBtnAction()
 
     appbtnmenu->addSeparator();
 
-//    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QDBusInterface iface("com.ukui.panel.desktop",
                          "/",
                          "com.ukui.panel.desktop",
@@ -342,7 +344,6 @@ void RightClickMenu::addAppBtnAction()
     connect(Add2DesktopAction, SIGNAL(triggered()),this,SLOT(addToDesktopActionTriggerSlot()));
 
 
-//    appbtnmenu->addSeparator();
     appbtnmenu->addAction(separatorAction_4);
 
     initWidgetAction(UninstallWid,":/data/img/mainviewwidget/uninstall.svg",tr("Uninstall"));
@@ -350,7 +351,6 @@ void RightClickMenu::addAppBtnAction()
     appbtnmenu->addAction(UninstallAction);
     connect(UninstallAction, SIGNAL(triggered()),this,SLOT(uninstallActionTriggerSlot()));
 
-//    appbtnmenu->addSeparator();
     appbtnmenu->addAction(separatorAction_5);
 
     initWidgetAction(AttributeWid,":/data/img/mainviewwidget/attributeaction.svg",tr("Attribute"));
@@ -366,40 +366,26 @@ void RightClickMenu::addAppBtnAction()
 //关机按钮右键菜单
 void RightClickMenu::addShutdownAction()
 {
-    shutdownmenu=new QMenu(this);
-    shutdownmenu->setLayoutDirection(Qt::LeftToRight);
-    shutdownmenu->setFixedSize(250+2,36*5+12+2);
-
-    LockScreenAction=new QWidgetAction(shutdownmenu);
-    LockScreenWid=new QWidget();
     initWidgetAction(LockScreenWid,":/data/img/sidebarwidget/lock.svg",tr("Lock"));
     LockScreenAction->setDefaultWidget(LockScreenWid);
     shutdownmenu->addAction(LockScreenAction);
     connect(LockScreenAction,SIGNAL(triggered()),this,SLOT(lockScreenActionTriggerSlot()));
 
-    SwitchUserAction=new QWidgetAction(shutdownmenu);
-    SwitchUserWid=new QWidget();
     initWidgetAction(SwitchUserWid,"",tr("Switch user"));
     SwitchUserAction->setDefaultWidget(SwitchUserWid);
     shutdownmenu->addAction(SwitchUserAction);
     connect(SwitchUserAction,SIGNAL(triggered()),this,SLOT(switchUserActionTriggerSlot()));
 
-    LogOutAction=new QWidgetAction(shutdownmenu);
-    LogOutWid=new QWidget();
     initWidgetAction(LogOutWid,"",tr("Sign out"));
     LogOutAction->setDefaultWidget(LogOutWid);
     shutdownmenu->addAction(LogOutAction);
     connect(LogOutAction,SIGNAL(triggered()),this,SLOT(logoutActionTriggerSlot()));
 
-    RebootAction=new QWidgetAction(shutdownmenu);
-    RebootWid=new QWidget();
     initWidgetAction(RebootWid,"",tr("Restart"));
     RebootAction->setDefaultWidget(RebootWid);
     shutdownmenu->addAction(RebootAction);
     connect(RebootAction,SIGNAL(triggered()),this,SLOT(rebootActionTriggerSlot()));
 
-    ShutDownAction=new QWidgetAction(shutdownmenu);
-    ShutDownWid=new QWidget();
     initWidgetAction(ShutDownWid,":/data/img/sidebarwidget/shutdown.svg",tr("Shut down"));
     ShutDownAction->setDefaultWidget(ShutDownWid);
     shutdownmenu->addAction(ShutDownAction);
@@ -413,13 +399,12 @@ void RightClickMenu::addShutdownAction()
 //其它按钮右键菜单
 void RightClickMenu::addOtherAction()
 {
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QDBusInterface iface("com.ukui.panel.desktop",
                          "/",
                          "com.ukui.panel.desktop",
                          QDBusConnection::sessionBus());
 
-    QDBusReply<bool> ret=iface.call("CheckIfExist",desktopfp);
+    QDBusReply<bool> ret=iface.call("CheckIfExist",this->desktopfp);
     if(!ret)
     {
         initWidgetAction(OtherFix2TaskBarWid,":/data/img/sidebarwidget/fixed.svg",tr("Pin to taskbar"));
@@ -499,11 +484,14 @@ void RightClickMenu::initWidgetAction(QWidget *wid, QString iconstr, QString tex
 void RightClickMenu::fixToCommonUseActionTriggerSlot()
 {
     action_number=1;
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
+    setting->beginGroup("lockapplication");
+    setting->setValue(desktopfn,setting->allKeys().size());
+    setting->sync();
+    setting->endGroup();
     setting->beginGroup("application");
-    setting->setValue(desktopfn,0);
+    setting->remove(desktopfn);
     setting->sync();
     setting->endGroup();
     setting->beginGroup("datetime");
@@ -515,11 +503,27 @@ void RightClickMenu::fixToCommonUseActionTriggerSlot()
 void RightClickMenu::unfixedFromCommonUseActionTriggerSlot()
 {
     action_number=2;
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
+    setting->beginGroup("lockapplication");
+    Q_FOREACH(QString desktop,setting->allKeys())
+    {
+        if(setting->value(desktop).toInt() > setting->value(desktopfn).toInt())
+        {
+            setting->setValue(desktop,setting->value(desktop).toInt()-1);
+        }
+    }
+    setting->remove(desktopfn);
+    setting->sync();
+    setting->endGroup();
     setting->beginGroup("application");
-    setting->setValue(desktopfn,2);
+    int maxValue=1;
+    Q_FOREACH(QString desktopfn,setting->allKeys())
+    {
+        if(setting->value(desktopfn).toInt()>maxValue)
+            maxValue=setting->value(desktopfn).toInt();
+    }
+    setting->setValue(desktopfn,maxValue+1);
     setting->sync();
     setting->endGroup();
     setting->beginGroup("datetime");
@@ -532,7 +536,6 @@ void RightClickMenu::unfixedFromCommonUseActionTriggerSlot()
 
 void RightClickMenu::fixToTaskbarActionTriggerSlot()
 {
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QDBusInterface iface("com.ukui.panel.desktop",
                          "/",
                          "com.ukui.panel.desktop",
@@ -544,7 +547,6 @@ void RightClickMenu::fixToTaskbarActionTriggerSlot()
 
 void RightClickMenu::unfixedFromTaskbarActionTriggerSlot()
 {
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QDBusInterface iface("com.ukui.panel.desktop",
                          "/",
                          "com.ukui.panel.desktop",
@@ -555,7 +557,6 @@ void RightClickMenu::unfixedFromTaskbarActionTriggerSlot()
 
 void RightClickMenu::addToDesktopActionTriggerSlot()
 {
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QString path=QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
@@ -575,7 +576,6 @@ void RightClickMenu::addToDesktopActionTriggerSlot()
 void RightClickMenu::uninstallActionTriggerSlot()
 {
 //    QString exec=pUkuiMenuInterface->getAppExec(pUkuiMenuInterface->getDesktopPathByAppName(appname));
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
 //    QFileInfo fileInfo(exec.split(" ").at(0));
 //    bool ret=fileInfo.isAbsolute();
 
@@ -618,7 +618,6 @@ void RightClickMenu::onReadOutput()
 
 void RightClickMenu::attributeActionTriggerSlot()
 {
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     char command[100];
     sprintf(command,"ukui-menu-attr %s",desktopfp.toLocal8Bit().data());
     QProcess::startDetached(command);
@@ -628,7 +627,6 @@ void RightClickMenu::attributeActionTriggerSlot()
 void RightClickMenu::commonUseDeleteActionTriggerSlot()
 {
     action_number=8;
-    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(appname);
     QFileInfo fileInfo(desktopfp);
     QString desktopfn=fileInfo.fileName();
     setting->beginGroup("application");
@@ -647,25 +645,17 @@ void RightClickMenu::commonUseDeleteAllActionTriggerSlot()
     QStringList deleteKeys;
     deleteKeys.clear();
     setting->beginGroup("application");
-    QStringList keys=setting->childKeys();
-    for(int i=0;i<keys.count();i++)
-    {
-        if(setting->value(keys.at(i)).toInt()==2)
-        {
-            setting->remove(keys.at(i));
-            deleteKeys.append(keys.at(i));
-        }
-    }
+    QStringList keys=setting->allKeys();
+    deleteKeys=keys;
+    setting->remove("");
     setting->sync();
     setting->endGroup();
 
+    setting->beginGroup("datetime");
     for(int i=0;i<deleteKeys.count();i++)
-    {
-        setting->beginGroup("datetime");
         setting->remove(deleteKeys.at(i));
-        setting->sync();
-        setting->endGroup();
-    }
+    setting->sync();
+    setting->endGroup();
 
 }
 
@@ -700,17 +690,19 @@ void RightClickMenu::otherListActionTriggerSlot()
     qDebug()<<"---2---";
 }
 
-int RightClickMenu::showCommonUseAppBtnMenu(QString appname)
+int RightClickMenu::showCommonUseAppBtnMenu(QString desktopfp)
 {
-    this->appname=appname;
+    this->desktopfp.clear();
+    this->desktopfp=desktopfp;
     addCommonUseAppBtnAction();
     cuappbtnmenu->exec(QCursor::pos());
     return action_number;
 }
 
-int RightClickMenu::showAppBtnMenu(QString appname)
+int RightClickMenu::showAppBtnMenu(QString desktopfp)
 {
-    this->appname=appname;
+    this->desktopfp.clear();
+    this->desktopfp=desktopfp;
     addAppBtnAction();
     appbtnmenu->exec(QCursor::pos());
     return action_number;
@@ -723,11 +715,10 @@ int RightClickMenu::showShutdownMenu()
 
 }
 
-void RightClickMenu::showOtherMenu(QString appname)
+void RightClickMenu::showOtherMenu(QString desktopfp)
 {
-    this->appname=appname;
+    this->desktopfp.clear();
+    this->desktopfp=desktopfp;
     addOtherAction();
     othermenu->exec(QCursor::pos());
 }
-
-
