@@ -33,6 +33,7 @@
 #include <QFileInfo>
 #include <QDBusInterface>
 #include <QProcess>
+#include <QEvent>
 #include "src/Interface/ukuimenuinterface.h"
 #include "src/Style/style.h"
 
@@ -42,13 +43,13 @@ class RightClickMenu: public QWidget
 public:
     RightClickMenu(QWidget *parent);
     virtual ~RightClickMenu();
-    int showCommonUseAppBtnMenu(QString appname);
-    int showAppBtnMenu(QString appname);
+    int showCommonUseAppBtnMenu(QString desktopfp);
+    int showAppBtnMenu(QString desktopfp);
     int showShutdownMenu();
-    void showOtherMenu(QString appname);
+    void showOtherMenu(QString desktopfp);
 
 private:
-    QString appname;
+    QString desktopfp;
     int action_number;//记录执行的action编号
     QSettings* setting=nullptr;
 
@@ -65,61 +66,61 @@ private:
     QWidgetAction* separatorAction_4=nullptr;
     QWidgetAction* separatorAction_5=nullptr;
 
-    QMenu* cuappbtnmenu;
-    QWidgetAction* CuFix2CommonUseAction;
-    QWidget* CuFix2CommonUseWid;
-    QWidgetAction* CuUnfixed4CommonUseAction;
-    QWidget* CuUnfixed4CommonUseWid;
-    QWidgetAction* CuFix2TaskBarAction;
-    QWidget* CuFix2TaskBarWid;
-    QWidgetAction* CuUnfixed4TaskBarAction;
-    QWidget* CuUnfixed4TaskBarWid;
-    QWidgetAction* CuAdd2DesktopAction;
-    QWidget* CuAdd2DesktopWid;
-    QWidgetAction* CuDeleteAction;
-    QWidget* CuDeleteWid;
+    QMenu* cuappbtnmenu=nullptr;
+    QWidgetAction* CuFix2CommonUseAction=nullptr;
+    QWidget* CuFix2CommonUseWid=nullptr;
+    QWidgetAction* CuUnfixed4CommonUseAction=nullptr;
+    QWidget* CuUnfixed4CommonUseWid=nullptr;
+    QWidgetAction* CuFix2TaskBarAction=nullptr;
+    QWidget* CuFix2TaskBarWid=nullptr;
+    QWidgetAction* CuUnfixed4TaskBarAction=nullptr;
+    QWidget* CuUnfixed4TaskBarWid=nullptr;
+    QWidgetAction* CuAdd2DesktopAction=nullptr;
+    QWidget* CuAdd2DesktopWid=nullptr;
+    QWidgetAction* CuDeleteAction=nullptr;
+    QWidget* CuDeleteWid=nullptr;
     QWidgetAction* CuDeleteAllAction;
-    QWidget* CuDeleteAllWid;
-    QWidgetAction* CuUninstallAction;
-    QWidget* CuUninstallWid;
-    QWidgetAction* CuAttributeAction;
-    QWidget* CuAttributeWid;
+    QWidget* CuDeleteAllWid=nullptr;
+    QWidgetAction* CuUninstallAction=nullptr;
+    QWidget* CuUninstallWid=nullptr;
+    QWidgetAction* CuAttributeAction=nullptr;
+    QWidget* CuAttributeWid=nullptr;
 
-    QMenu* appbtnmenu;
-    QWidgetAction* Fix2CommonUseAction;
-    QWidget* Fix2CommonUseWid;
-    QWidgetAction* Unfixed4CommonUseAction;
-    QWidget* Unfixed4CommonUseWid;
-    QWidgetAction* Fix2TaskBarAction;
-    QWidget* Fix2TaskBarWid;
-    QWidgetAction* Unfixed4TaskBarAction;
-    QWidget* Unfixed4TaskBarWid;
-    QWidgetAction* Add2DesktopAction;
-    QWidget* Add2DesktopWid;
-    QWidgetAction* UninstallAction;
-    QWidget* UninstallWid;
-    QWidgetAction* AttributeAction;
-    QWidget* AttributeWid;
+    QMenu* appbtnmenu=nullptr;
+    QWidgetAction* Fix2CommonUseAction=nullptr;
+    QWidget* Fix2CommonUseWid=nullptr;
+    QWidgetAction* Unfixed4CommonUseAction=nullptr;
+    QWidget* Unfixed4CommonUseWid=nullptr;
+    QWidgetAction* Fix2TaskBarAction=nullptr;
+    QWidget* Fix2TaskBarWid=nullptr;
+    QWidgetAction* Unfixed4TaskBarAction=nullptr;
+    QWidget* Unfixed4TaskBarWid=nullptr;
+    QWidgetAction* Add2DesktopAction=nullptr;
+    QWidget* Add2DesktopWid=nullptr;
+    QWidgetAction* UninstallAction=nullptr;
+    QWidget* UninstallWid=nullptr;
+    QWidgetAction* AttributeAction=nullptr;
+    QWidget* AttributeWid=nullptr;
 
-    QMenu* shutdownmenu;
-    QWidgetAction* LockScreenAction;
-    QWidget* LockScreenWid;
-    QWidgetAction* SwitchUserAction;
-    QWidget* SwitchUserWid;
-    QWidgetAction* LogOutAction;
-    QWidget* LogOutWid;
-    QWidgetAction* RebootAction;
-    QWidget* RebootWid;
-    QWidgetAction* ShutDownAction;
-    QWidget* ShutDownWid;
+    QMenu* shutdownmenu=nullptr;
+    QWidgetAction* LockScreenAction=nullptr;
+    QWidget* LockScreenWid=nullptr;
+    QWidgetAction* SwitchUserAction=nullptr;
+    QWidget* SwitchUserWid=nullptr;
+    QWidgetAction* LogOutAction=nullptr;
+    QWidget* LogOutWid=nullptr;
+    QWidgetAction* RebootAction=nullptr;
+    QWidget* RebootWid=nullptr;
+    QWidgetAction* ShutDownAction=nullptr;
+    QWidget* ShutDownWid=nullptr;
 
-    QMenu* othermenu;
-    QWidgetAction* OtherFix2TaskBarAction;
-    QWidget* OtherFix2TaskBarWid;
-    QWidgetAction* OtherUnfix2TaskBarAction;
-    QWidget* OtherUnfix2TaskBarWid;
-    QWidgetAction* OtherListAction;
-    QWidget* OtherListWid;
+    QMenu* othermenu=nullptr;
+    QWidgetAction* OtherFix2TaskBarAction=nullptr;
+    QWidget* OtherFix2TaskBarWid=nullptr;
+    QWidgetAction* OtherUnfix2TaskBarAction=nullptr;
+    QWidget* OtherUnfix2TaskBarWid=nullptr;
+    QWidgetAction* OtherListAction=nullptr;
+    QWidget* OtherListWid=nullptr;
 
     UkuiMenuInterface* pUkuiMenuInterface=nullptr;
 
