@@ -59,9 +59,8 @@ private Q_SLOTS:
     void execApplication(QString appname);//执行应用程序
 
 Q_SIGNALS:
-    void sendUpdateAppListSignal();//向CommonUseWidget发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向CommonUseWidget发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
-
 };
 
 #endif // FULLSEARCHRESULTWIDGET_H
