@@ -50,13 +50,11 @@ void SearchResultWidget::initWidget()
     mainLayout->addWidget(listview);
     this->setLayout(mainLayout);
     data.clear();
-    itemdelegate=new ItemDelegate(this,3);
-    listview->setItemDelegate(itemdelegate);
     listview->addData(data);
     pUkuiMenuInterface=new UkuiMenuInterface;
 
     connect(listview,SIGNAL(sendItemClickedSignal(QStringList)),this,SLOT(execApplication(QStringList)));
-    connect(listview,SIGNAL(sendFixedOrUnfixedSignal()),this,SIGNAL(sendUpdateAppListSignal()));
+    connect(listview,SIGNAL(sendFixedOrUnfixedSignal(QString,int)),this,SIGNAL(sendUpdateAppListSignal(QString,int)));
     connect(listview,SIGNAL(sendHideMainWindowSignal()),this,SIGNAL(sendHideMainWindowSignal()));
 }
 
@@ -84,7 +82,4 @@ void SearchResultWidget::updateAppListView(QStringList desktopfplist)
         data.append(QStringList()<<desktopfplist.at(i)<<"1");
     }
     listview->updateData(data);
-//    itemdelegate=new FullItemDelegate(this,3);
-//    listview->setItemDelegate(itemdelegate);
-//    listview->addData(data);
 }
