@@ -52,7 +52,6 @@ private:
 
     QHBoxLayout* mainLayout=nullptr;
     ListView* listview=nullptr;
-    ItemDelegate* itemdelegate=nullptr;
     QVector<QStringList> data;
 
 protected:
@@ -62,7 +61,7 @@ private Q_SLOTS:
     void execApplication(QStringList arg);//执行应用程序
 
 Q_SIGNALS:
-    void sendUpdateAppListSignal();//向常用软件模块发送更新应用列表信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向常用软件模块发送更新应用列表信号
     void sendHideMainWindowSignal();//向MainViewWidget发送隐藏主窗口信号
 };
 
