@@ -42,7 +42,9 @@ int Style::LeftMargin=0;
 int Style::RightMargin=0;
 int Style::LeftBtnWidth=0;
 int Style::LeftBtnHeight=0;
+int Style::LeftLetterBtnHeight=0;
 int Style::LeftFontSize=0;
+int Style::LeftLetterFontSize=0;
 int Style::LeftIconSize=0;
 int Style::LeftSpaceIconLeft=0;
 int Style::LeftSpaceIconText=0;
@@ -78,51 +80,62 @@ int Style::SideBarSpaceBetweenItem=0;
 
 void Style::initWidStyle()
 {
-    QDBusInterface iface("com.ukui.panel.desktop",
-                         "/",
-                         "com.ukui.panel.desktop",
-                         QDBusConnection::sessionBus());
+    QGSettings* setting=new QGSettings(QString("org.mate.interface").toLocal8Bit());
+    QString value=setting->get("font-name").toString();
+    QStringList valstr=value.split(" ");
+    int fontSize=valstr.at(valstr.count()-1).toInt();
+
+    QFileInfo fileInfo(QString("/usr/share/glib-2.0/schemas/org.ukui.panel.settings.gschema.xml"));
+    int position=0;
+    int panelSize=0;
+    if(fileInfo.exists())
+    {
+        QGSettings* gsetting=new QGSettings(QString("org.ukui.panel.settings").toLocal8Bit());
+        position=gsetting->get("panelposition").toInt();
+        panelSize=gsetting->get("panelsize").toInt();
+    }
+    else
+    {
+        position=0;
+        panelSize=46;
+    }
+
 
-    QDBusReply<int> position=iface.call("GetPanelPosition","");
-    QDBusReply<int> panelSize=iface.call("GetPanelSize","");
-//    int widthavailable=0;
-//    int heightavailable=0;
     if(position==0 || position==1)
     {
-        widthavailable=QApplication::desktop()->width();
-        heightavailable=QApplication::desktop()->height()-panelSize;
+        widthavailable=QApplication::primaryScreen()->geometry().width();
+        heightavailable=QApplication::primaryScreen()->geometry().height()-panelSize;
     }
     if(position==2 || position==3)
     {
-        widthavailable=QApplication::desktop()->width()-panelSize;
-        heightavailable=QApplication::desktop()->height();
+        widthavailable=QApplication::primaryScreen()->geometry().width()-panelSize;
+        heightavailable=QApplication::primaryScreen()->geometry().height();
     }
 
-    QApplication::desktop()->width();
-//    int height=QApplication::desktop()->height();
-//    int heightavailable=QApplication::desktop()->availableGeometry().height();
     if(widthavailable>=2000 && widthavailable<=4000)
     {
         MainViewWidWidth=widthavailable-round((widthavailable-1440)/2);
         TopWidgetHeight=107;
         QueryLineEditWidth=350;
         QueryLineEditHeight=30;
-        QueryLineEditFontSize=14;
+        QueryLineEditFontSize=fontSize;
         QueryLineEditIconSize=16;
         LeftWidWidth=round((widthavailable-1440)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
+        LeftMargin=20;
         LeftBtnWidth=100;
         LeftBtnHeight=43;
-        LeftMargin=20;
+        LeftLetterBtnHeight=43;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=16;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=14;
         LeftIconSize=19;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=15;
         AppListWidWidth=1440;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=14;
+        AppListFontSize=fontSize;
         AppListIconSize=96;
         AppListItemSizeWidth=168;
         AppListGridSizeWidth=204;
@@ -140,7 +153,7 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
         SideBarSpaceIconText=9;
@@ -151,22 +164,24 @@ void Style::initWidStyle()
         TopWidgetHeight=107;
         QueryLineEditWidth=350;
         QueryLineEditHeight=30;
-        QueryLineEditFontSize=14;
+        QueryLineEditFontSize=fontSize;
         QueryLineEditIconSize=16;
         LeftWidWidth=round((widthavailable-1314)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
+        LeftMargin=20;
         LeftBtnWidth=100;
         LeftBtnHeight=43;
-        LeftMargin=20;
+        LeftLetterBtnHeight=43;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=16;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=14;
         LeftIconSize=19;
         LeftSpaceIconLeft=15;
         LeftSpaceIconText=14;
         LeftSpaceBetweenItem=15;
         AppListWidWidth=1314;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=14;
+        AppListFontSize=fontSize;
         AppListIconSize=86;
         AppListItemSizeWidth=150;
         AppListGridSizeWidth=186;
@@ -184,7 +199,7 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
         SideBarSpaceIconText=9;
@@ -193,24 +208,26 @@ void Style::initWidStyle()
     else if (widthavailable>=1600 && widthavailable<1920) {
         MainViewWidWidth=widthavailable-round((widthavailable-1090)/2);
         TopWidgetHeight=107;
-        QueryLineEditWidth=260;
-        QueryLineEditHeight=22;
-        QueryLineEditFontSize=11;
-        QueryLineEditIconSize=12;
+        QueryLineEditWidth=280;
+        QueryLineEditHeight=24;
+        QueryLineEditFontSize=fontSize;
+        QueryLineEditIconSize=14;
         LeftWidWidth=round((widthavailable-1090)/2);
-        LeftBtnHeight=heightavailable-TopWidgetHeight;
+        LeftWidHeight=heightavailable-TopWidgetHeight;
+        LeftMargin=10;
         LeftBtnWidth=74;
         LeftBtnHeight=32;
-        LeftMargin=10;
+        LeftLetterBtnHeight=32;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=12;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=11;
         LeftIconSize=14;
         LeftSpaceIconLeft=11;
         LeftSpaceIconText=9;
         LeftSpaceBetweenItem=10;
         AppListWidWidth=1090;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=12;
+        AppListFontSize=fontSize;
         AppListIconSize=86;
         AppListItemSizeWidth=150;
         AppListGridSizeWidth=180;
@@ -220,8 +237,6 @@ void Style::initWidStyle()
 //        AppBottomSpace=static_cast<int>(round(27*0.84));
         SliderSize=10;
 
-        qDebug()<<"style:"<<QApplication::desktop()->availableGeometry().height()<<heightavailable<<AppListWidHeight;
-
         SideBarWidWidth=round((widthavailable-1090)/2);
         SideBarMargin=10;
         MinMaxWidWidth=110;
@@ -230,33 +245,35 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
-        SideBarSpaceIconText=9;
+        SideBarSpaceIconText=6;
         SideBarSpaceBetweenItem=16;
     }
     else if (widthavailable>=1366 && widthavailable<1600) {
         MainViewWidWidth=widthavailable-round((widthavailable-850)/2);
         TopWidgetHeight=round(107*0.78);
-        QueryLineEditWidth=260;
-        QueryLineEditHeight=22;
-        QueryLineEditFontSize=11;
-        QueryLineEditIconSize=12;
+        QueryLineEditWidth=280;
+        QueryLineEditHeight=24;
+        QueryLineEditFontSize=fontSize;
+        QueryLineEditIconSize=14;
         LeftWidWidth=round((widthavailable-850)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
         LeftMargin=10;
         LeftBtnWidth=74;
         LeftBtnHeight=32;
+        LeftLetterBtnHeight=32;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=12;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=11;
         LeftIconSize=14;
         LeftSpaceIconLeft=11;
         LeftSpaceIconText=9;
         LeftSpaceBetweenItem=10;
         AppListWidWidth=850;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=12;
+        AppListFontSize=fontSize;
         AppListIconSize=64;
         AppListItemSizeWidth=112;
         AppListGridSizeWidth=140;
@@ -274,33 +291,35 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
-        SideBarSpaceIconText=9;
+        SideBarSpaceIconText=6;
         SideBarSpaceBetweenItem=16;
     }
     else if (widthavailable>=1280 && widthavailable<1366) {
         MainViewWidWidth=widthavailable-round((widthavailable-718)/2);
         TopWidgetHeight=round(107*0.78);
-        QueryLineEditWidth=260;
-        QueryLineEditHeight=22;
-        QueryLineEditFontSize=11;
-        QueryLineEditIconSize=12;
+        QueryLineEditWidth=280;
+        QueryLineEditHeight=24;
+        QueryLineEditFontSize=fontSize;
+        QueryLineEditIconSize=14;
         LeftWidWidth=round((widthavailable-718)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
         LeftMargin=10;
         LeftBtnWidth=74;
         LeftBtnHeight=32;
+        LeftLetterBtnHeight=32;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=12;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=11;
         LeftIconSize=14;
         LeftSpaceIconLeft=11;
         LeftSpaceIconText=9;
         LeftSpaceBetweenItem=10;
         AppListWidWidth=718;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=12;
+        AppListFontSize=fontSize;
         AppListIconSize=64;
         AppListItemSizeWidth=112;
         AppListGridSizeWidth=142;
@@ -318,33 +337,35 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
-        SideBarSpaceIconText=9;
+        SideBarSpaceIconText=6;
         SideBarSpaceBetweenItem=16;
     }
     else if (widthavailable>=1152 && widthavailable<1280) {
         MainViewWidWidth=widthavailable-round((widthavailable-718)/2);
         TopWidgetHeight=round(107*0.78);
-        QueryLineEditWidth=260;
-        QueryLineEditHeight=22;
-        QueryLineEditFontSize=11;
-        QueryLineEditIconSize=12;
+        QueryLineEditWidth=280;
+        QueryLineEditHeight=24;
+        QueryLineEditFontSize=fontSize;
+        QueryLineEditIconSize=14;
         LeftWidWidth=round((widthavailable-718)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
         LeftMargin=10;
         LeftBtnWidth=74;
         LeftBtnHeight=32;
+        LeftLetterBtnHeight=32;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=12;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=11;
         LeftIconSize=14;
         LeftSpaceIconLeft=11;
         LeftSpaceIconText=9;
         LeftSpaceBetweenItem=10;
         AppListWidWidth=718;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=12;
+        AppListFontSize=fontSize;
         AppListIconSize=64;
         AppListItemSizeWidth=112;
         AppListGridSizeWidth=142;
@@ -362,33 +383,35 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
-        SideBarSpaceIconText=9;
+        SideBarSpaceIconText=6;
         SideBarSpaceBetweenItem=16;
     }
     else {
         MainViewWidWidth=widthavailable-round((widthavailable-572)/2);
         TopWidgetHeight=round(107*0.78);
-        QueryLineEditWidth=260;
-        QueryLineEditHeight=22;
-        QueryLineEditFontSize=11;
-        QueryLineEditIconSize=12;
+        QueryLineEditWidth=280;
+        QueryLineEditHeight=24;
+        QueryLineEditFontSize=fontSize;
+        QueryLineEditIconSize=14;
         LeftWidWidth=round((widthavailable-572)/2);
         LeftWidHeight=heightavailable-TopWidgetHeight;
         LeftMargin=10;
         LeftBtnWidth=74;
         LeftBtnHeight=32;
+        LeftLetterBtnHeight=32;
         RightMargin=LeftWidWidth-LeftMargin-LeftBtnWidth;
-        LeftFontSize=12;
+        LeftFontSize=fontSize;
+        LeftLetterFontSize=11;
         LeftIconSize=14;
         LeftSpaceIconLeft=11;
         LeftSpaceIconText=9;
         LeftSpaceBetweenItem=10;
         AppListWidWidth=572;
         AppListWidHeight=heightavailable-TopWidgetHeight;
-        AppListFontSize=12;
+        AppListFontSize=fontSize;
         AppListIconSize=64;
         AppListItemSizeWidth=112;
         AppListGridSizeWidth=141;
@@ -406,10 +429,10 @@ void Style::initWidStyle()
         MinMaxIconSize=19;
         SideBarBtnWidth=110;
         SideBarBtnHeight=43;
-        SideBarFontSize=14;
+        SideBarFontSize=fontSize;
         SideBarIconSize=19;
         SideBarSpaceIconLeft=14;
-        SideBarSpaceIconText=9;
+        SideBarSpaceIconText=6;
         SideBarSpaceBetweenItem=16;
     }
 }
