@@ -24,6 +24,9 @@
 #include <QDBusConnection>
 #include <QDBusReply>
 #include <QDBusInterface>
+#include <qgsettings.h>
+#include <QScreen>
+#include <QFileInfo>
 
 //颜色
 #define BORDERCOLOR "rgba(37,41,43)" //边框
@@ -101,7 +104,9 @@ public:
     static int RightMargin;//内右侧边距
     static int LeftBtnWidth;//按钮宽度
     static int LeftBtnHeight;//按钮高度
+    static int LeftLetterBtnHeight;//按钮高度
     static int LeftFontSize; //字体大小
+    static int LeftLetterFontSize; //字体大小
     static int LeftIconSize; //图标大小
     static int LeftSpaceIconLeft; //按钮内左侧边距
     static int LeftSpaceIconText; //按钮图标与文字内边距
