@@ -38,6 +38,7 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
     if(index.isValid())
     {
         painter->save();
+        QStyleOptionViewItem viewOption(option);//用来在视图中画一个item
         QRectF rect;
         rect.setX(option.rect.x());
         rect.setY(option.rect.y());
@@ -57,24 +58,6 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
         path.lineTo(rect.topRight() + QPointF(0, radius));
         path.quadTo(rect.topRight(), rect.topRight() + QPointF(-radius, -0));
 
-//        if(option.state.testFlag(QStyle::State_Selected))
-//        {
-//            painter->setPen(QPen(Qt::blue));
-//            painter->setBrush(QColor(229, 241, 255));
-//            painter->drawPath(path);
-//        }
-//        else if(option.state.testFlag(QStyle::State_MouseOver))
-//        {
-//            painter->setPen(QPen(Qt::green));
-//            painter->setBrush(Qt::NoBrush);
-//            painter->drawPath(path);
-//        }
-//        else{
-//            painter->setPen(QPen(Qt::gray));
-//            painter->setBrush(Qt::NoBrush);
-//            painter->drawPath(path);
-//        }
-
         painter->setRenderHint(QPainter::Antialiasing);
         if(option.state & QStyle::State_MouseOver)
         {
@@ -88,33 +71,38 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
         }
 
         painter->setOpacity(1);
-        QIcon icon=index.data(Qt::DecorationRole).value<QIcon>();
+//        QIcon icon=index.data(Qt::DecorationRole).value<QIcon>();
         QString desktopfp=index.data(Qt::DisplayRole).value<QString>();
+//        QString desktopfp=index.data().value<QString>();
+        QString iconstr=pUkuiMenuInterface->getAppIcon(desktopfp);
+        iconstr.remove(".png");
+        iconstr.remove(".svg");
+        QIcon icon=QIcon::fromTheme(iconstr);
+        if(icon.isNull())
+            icon=QIcon::fromTheme(QString("application-x-desktop"));
         QString appname=pUkuiMenuInterface->getAppName(desktopfp);
 
-        QFont font;
+//        QFont font;
         QRect iconRect;
-        font.setPixelSize(Style::AppListFontSize);
+//        font.setPixelSize(Style::AppListFontSize);
         iconRect=QRect(rect.x()+Style::AppLeftSpace ,
                        rect.y()+Style::AppTopSpace,
                        Style::AppListIconSize,
                        Style::AppListIconSize);
-        painter->setFont(font);
+//        painter->setFont(font);
         icon.paint(painter,iconRect);
         if(module==0)
         {
-            setting->beginGroup("application");
+            setting->beginGroup("lockapplication");
             QFileInfo fileInfo(desktopfp);
             QString desktopfn=fileInfo.fileName();
-            if(setting->value(desktopfn).toInt()==0)
+            if(setting->contains(desktopfn))
             {
                 QIcon icon(QString(":/data/img/mainviewwidget/lock-fs.svg"));
                 icon.paint(painter,QRect(iconRect.topRight().x()-14,iconRect.topRight().y()-2,16,16));
-//                painter->drawImage(QRect(iconRect.topRight().x()-8,iconRect.topRight().y(),16,16),
-//                                   icon.pixmap(icon.actualSize(QSize(16, 16))).toImage());
+//                icon.paint(painter,QRect(rect.topRight().x()-18,rect.topRight().y()+6,12,12));
             }
             setting->endGroup();
-
         }
 
         painter->setPen(QPen(Qt::white));
@@ -126,10 +114,8 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
                        rect.height()-iconRect.height()-Style::AppSpaceBetweenIconText);
         QFontMetrics fm=painter->fontMetrics();
         QString appnameElidedText=fm.elidedText(appname,Qt::ElideRight,rect.width(),Qt::TextShowMnemonic);
-//        painter->drawText(textRect,Qt::TextWordWrap |Qt::AlignHCenter | Qt::AlignTop,appname);
         painter->drawText(textRect,Qt::AlignHCenter |Qt::AlignTop,appnameElidedText);
 
-//        painter->setRenderHint(QPainter::Antialiasing);
         if(option.state & QStyle::State_MouseOver)
         {
 //            painter->setPen(QPen(Qt::NoPen));
@@ -155,6 +141,11 @@ void FullItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
     }
 }
 
+QSize FullItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+    return QSize(Style::AppListItemSizeWidth, Style::AppListItemSizeWidth);
+}
+
 //bool FullItemDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, const QStyleOptionViewItem &option, const QModelIndex &index)
 //{
 //    if(event->type()==QEvent::ToolTip)
