@@ -67,41 +67,39 @@ void FullListView::initWidget()
     this->setTextElideMode(Qt::ElideRight);
     this->setMouseTracking(true);
     this->setFocusPolicy(Qt::NoFocus);
+//    this->setAcceptDrops(false);
+    this->setMovement(QListView::Static);
 //    this->setUpdatesEnabled(true);
 
 //    this->setSpacing(32);
     this->setGridSize(QSize(Style::AppListGridSizeWidth,Style::AppListGridSizeWidth));
     connect(this,SIGNAL(customContextMenuRequested(QPoint)),this,SLOT(rightClickedSlot()));
     connect(this,SIGNAL(clicked(QModelIndex)),this,SLOT(onClicked(QModelIndex)));
-    connect(this,SIGNAL(entered(QModelIndex)),this,SLOT(showToolTip(QModelIndex)));
 }
 
 void FullListView::addData(QStringList data)
 {
+    listmodel=new QStandardItemModel(this);
+    this->setModel(listmodel);
+    Q_FOREACH(QString desktopfp,data)
+    {
+        QStandardItem* item=new QStandardItem;
+        item->setData(QVariant::fromValue<QString>(desktopfp),Qt::DisplayRole);
+        listmodel->appendRow(item);
+    }
     m_delegate= new FullItemDelegate(this,module);
     this->setItemDelegate(m_delegate);
-    listmodel=new FullListModel(this);
-    this->setModel(listmodel);
-    listmodel->setData(data);
 }
 
 void FullListView::updateData(QStringList data)
 {
-    m_delegate->setParent(nullptr);
-    delete m_delegate;
-    m_delegate=new FullItemDelegate(this,module);
-    this->setItemDelegate(m_delegate);
-    listmodel->updateData(data);
-}
-
-void FullListView::removeRow(QString desktopfp)
-{
-    listmodel->removeRow(desktopfp);
-}
-
-void FullListView::insertRow(QString desktopfp)
-{
-    listmodel->insertRow(desktopfp);
+    listmodel->clear();
+    Q_FOREACH(QString desktopfp,data)
+    {
+        QStandardItem* item=new QStandardItem;
+        item->setData(QVariant::fromValue<QString>(desktopfp),Qt::DisplayRole);
+        listmodel->appendRow(item);
+    }
 }
 
 void FullListView::onClicked(QModelIndex index)
@@ -123,54 +121,69 @@ void FullListView::rightClickedSlot()
         QModelIndex index=this->currentIndex();
         QVariant var=listmodel->data(index, Qt::DisplayRole);
         QString desktopfp=var.value<QString>();
-        QString appname=pUkuiMenuInterface->getAppName(desktopfp);
         menu=new RightClickMenu(this);
         if(module>0)
         {
-            int ret=menu->showAppBtnMenu(appname);
-            if(ret==1 || ret==2)
-            {
-                Q_EMIT sendFixedOrUnfixedSignal();
-            }
+            int ret=menu->showAppBtnMenu(desktopfp);
+            if(ret==1)
+                Q_EMIT sendFixedOrUnfixedSignal(desktopfp,0);
+            if(ret==2)
+                Q_EMIT sendFixedOrUnfixedSignal(desktopfp,1);
+            if(ret==6)
+                Q_EMIT sendHideMainWindowSignal();
             if(ret==7)
                 Q_EMIT sendHideMainWindowSignal();
         }
         else{
-            int ret=menu->showCommonUseAppBtnMenu(appname);
-            if(ret==1 || ret==2)
+            int ret=menu->showCommonUseAppBtnMenu(desktopfp);
+            if(ret==1)
             {
                 this->setCurrentIndex(index);
+                listmodel->removeRow(index.row());
+                setting->beginGroup("lockapplication");
+                QStandardItem* item=new QStandardItem;
+                item->setData(QVariant::fromValue<QString>(desktopfp),Qt::DisplayRole);
+                listmodel->insertRow(setting->allKeys().size()-1,item);
+                setting->endGroup();
+                Q_EMIT sendUpdateAppListSignal(desktopfp,0);
+            }
+            if(ret==2)
+            {
+                listmodel->removeRow(index.row());
+                setting->beginGroup("lockapplication");
+                QStandardItem* item=new QStandardItem;
+                item->setData(QVariant::fromValue<QString>(desktopfp),Qt::DisplayRole);
+                listmodel->insertRow(setting->allKeys().size(),item);
+                setting->endGroup();
+                Q_EMIT sendUpdateAppListSignal(desktopfp,1);
             }
 
             if(ret==7)
                 Q_EMIT sendHideMainWindowSignal();
 
-            if(ret==8 || ret==9)
+            if(ret==8)
             {
-                QStringList keys;
-                keys.clear();
-                setting->beginGroup("application");
-                keys=setting->childKeys();
-                QStringList applist;
-                applist.clear();
-                for(int i=0;i<keys.count();i++)
-                {
-                    int val=setting->value(keys.at(i)).toInt();
-                    if(val==2 || val==0)
-                        applist.append(keys.at(i));
-                }
-
-                data.clear();
-                for(int i=0;i<applist.count();i++)
-                {
-//                    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(applist.at(i));
-                    QString desktopfp=QString("/usr/share/applications/"+applist.at(i));
-                    data.append(desktopfp);
-                }
-                this->updateData(data);
-                setting->endGroup();
-                Q_EMIT sendUpdateAppListSignal();
+                listmodel->removeRow(index.row());
+                Q_EMIT removeListItemSignal(desktopfp);
             }
+
+            if(ret==9)
+            {
+                setting->beginGroup("lockapplication");
+                for(int i=listmodel->rowCount()-1;i>=0;i--)
+                {
+                    QVariant var=listmodel->index(i,0).data(Qt::DisplayRole);
+                    QString desktopfp=var.value<QString>();
+                    QFileInfo fileInfo(desktopfp);
+                    QString desktopfn=fileInfo.fileName();
+                    if(!setting->contains(desktopfn))
+                        listmodel->removeRow(i);
+                }
+                setting->endGroup();
+                Q_EMIT removeListAllItemSignal();
+            }
+            if(ret==6)
+                Q_EMIT sendHideMainWindowSignal();
         }
 
         this->selectionModel()->clear();
@@ -188,39 +201,3 @@ void FullListView::leaveEvent(QEvent *e)
     Q_UNUSED(e);
     this->verticalScrollBar()->setVisible(false);
 }
-
-void FullListView::showToolTip(const QModelIndex &index)
-{
-//    qDebug()<<this->y()<<this->visualRect(index).y();
-//    if(!index.isValid())
-//        return;
-
-//    QVariant var=listmodel->data(index, Qt::DisplayRole);
-//    QString desktopfp=var.value<QString>();
-//    QString appname=pUkuiMenuInterface->getAppName(desktopfp);
-
-////    if(file_name.isEmpty())
-////        return;
-
-//    QToolTip::showText(QCursor::pos(), appname,this);
-//    QToolTip::hideText();
-}
-
-//bool FullListView::event(QEvent* e)
-//{
-//    if (e->type() == QEvent::ToolTip) {
-//        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(e);
-//        QModelIndex index=this->currentIndex();
-//        QVariant var=listmodel->data(index, Qt::DisplayRole);
-//        QString desktopfp=var.value<QString>();
-//        QString appname=pUkuiMenuInterface->getAppName(desktopfp);
-//        if (!appname.isEmpty()) {
-//            QToolTip::showText(helpEvent->globalPos(), appname);
-//        } else {
-//            QToolTip::hideText();
-//            e->ignore();
-//        }
-//        return true;
-//    }
-//    return QWidget::event(e);
-//}
