@@ -25,8 +25,8 @@
 #include <QEvent>
 #include <QScrollBar>
 #include <QToolTip>
+#include <QStandardItemModel>
 #include "fullitemdelegate.h"
-#include "fulllistmodel.h"
 #include "src/Style/style.h"
 
 class FullListView : public QListView
@@ -38,21 +38,18 @@ public:
 
     void addData(QStringList data);//字母排序模块添加数据
     void updateData(QStringList data);
-    void removeRow(QString desktopfp);
-    void insertRow(QString desktopfp);
 
 protected:
     void initWidget();
     void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
     void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;
-//    bool event(QEvent* e) Q_DECL_OVERRIDE;
 
 private:
     FullItemDelegate* m_delegate=nullptr;
-    FullListModel* listmodel=nullptr;
+    QStandardItemModel* listmodel=nullptr;
     int module=0;
 
-    RightClickMenu* menu;//右键菜单
+    RightClickMenu* menu=nullptr;//右键菜单
     QSettings *setting=nullptr;
     QStringList data;
 
@@ -61,12 +58,13 @@ private:
 private Q_SLOTS:
     void onClicked(QModelIndex index);//点击item
     void rightClickedSlot();//右键菜单
-    void showToolTip(const QModelIndex &index);
 
 Q_SIGNALS:
     void sendItemClickedSignal(QString arg);//向字母排序或功能分类模块发送item点击信号
-    void sendFixedOrUnfixedSignal();//向字母排序、功能分类发送固定或者取消固定信号
-    void sendUpdateAppListSignal();//向FullCommonUseWidget发送更新应用列表信号
+    void sendFixedOrUnfixedSignal(QString desktopfp,int type);//向字母排序、功能分类发送固定或者取消固定信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向FullCommonUseWidget发送更新应用列表信号
+    void removeListItemSignal(QString desktopfp);
+    void removeListAllItemSignal();
     void sendHideMainWindowSignal();
 };
 
