@@ -47,6 +47,7 @@ FunctionClassifyButton::FunctionClassifyButton(QWidget *parent,
     this->text=text;
     this->is_fullscreen=is_fullscreen;
     this->enabled=enabled;
+    this->setCheckable(true);
 
     this->setFocusPolicy(Qt::NoFocus);
     svgRender=new QSvgRenderer(this);
@@ -62,9 +63,9 @@ FunctionClassifyButton::FunctionClassifyButton(QWidget *parent,
 
     textlabel=new QLabel(this);
     textlabel->setText(this->text);
-    QFont font;
-    font.setPixelSize(textSize);
-    textlabel->setFont(font);
+//    QFont font;
+//    font.setPixelSize(textSize);
+//    textlabel->setFont(font);
     if(is_fullscreen)
         textlabel->setStyleSheet("background:transparent; color:rgba(255, 255, 255, 50%);");
     else
@@ -82,6 +83,7 @@ FunctionClassifyButton::FunctionClassifyButton(QWidget *parent,
     this->setLayout(mainlayout);
     mainlayout->addWidget(iconlabel);
     mainlayout->addWidget(textlabel);
+    connect(this,SIGNAL(toggled(bool)),this,SLOT(reactToToggle(bool)));
 }
 
 void FunctionClassifyButton::enterEvent(QEvent *e)
@@ -105,9 +107,9 @@ void FunctionClassifyButton::enterEvent(QEvent *e)
     svgRender->render(&p);
     iconlabel->setPixmap(*pixmap);
     iconlabel->setFixedSize(pixmap->size());
-    QFont font;
-    font.setPixelSize(textSize);
-    textlabel->setFont(font);
+//    QFont font;
+//    font.setPixelSize(textSize);
+//    textlabel->setFont(font);
     if(enabled)
         textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255);");
     textlabel->adjustSize();
@@ -124,9 +126,9 @@ void FunctionClassifyButton::leaveEvent(QEvent *e)
         this->setFixedSize(width,height);
         svgRender->load(piconstr);
         pixmap=new QPixmap(iconSize,iconSize);
-        QFont font;
-        font.setPixelSize(textSize);
-        textlabel->setFont(font);
+//        QFont font;
+//        font.setPixelSize(textSize);
+//        textlabel->setFont(font);
 
     }
     else
@@ -134,9 +136,9 @@ void FunctionClassifyButton::leaveEvent(QEvent *e)
         this->setFixedSize(width,height);
         svgRender->load(iconstr);
         pixmap=new QPixmap(iconSize,iconSize);
-        QFont font;
-        font.setPixelSize(textSize);
-        textlabel->setFont(font);
+//        QFont font;
+//        font.setPixelSize(textSize);
+//        textlabel->setFont(font);
 
     }
 //    pixmap=new QPixmap(iconSize,iconSize);
@@ -175,9 +177,9 @@ void FunctionClassifyButton::mousePressEvent(QMouseEvent *event)
         svgRender->render(&p);
         iconlabel->setPixmap(*pixmap);
         iconlabel->setFixedSize(pixmap->size());
-        QFont font;
-        font.setPixelSize(textSize);
-        textlabel->setFont(font);
+//        QFont font;
+//        font.setPixelSize(textSize);
+//        textlabel->setFont(font);
         textlabel->setStyleSheet("background:transparent;color:#ffffff;");
         textlabel->adjustSize();
         is_pressed=true;
@@ -203,14 +205,44 @@ void FunctionClassifyButton::mouseReleaseEvent(QMouseEvent *event)
         svgRender->render(&p);
         iconlabel->setPixmap(*pixmap);
         iconlabel->setFixedSize(pixmap->size());
-        QFont font;
-        font.setPixelSize(textSize);
-        textlabel->setFont(font);
+//        QFont font;
+//        font.setPixelSize(textSize);
+//        textlabel->setFont(font);
         textlabel->setStyleSheet("background:transparent;color:#ffffff;");
         textlabel->adjustSize();
         Q_EMIT buttonClicked(this);
     }
 }
 
-
-
+void FunctionClassifyButton::reactToToggle(bool checked)
+{
+    if(checked)
+    {
+        delete svgRender;
+        svgRender=new QSvgRenderer(this);
+        svgRender->load(piconstr);
+        pixmap=new QPixmap(iconSize,iconSize);
+        pixmap->fill(Qt::transparent);
+        QPainter p(pixmap);
+        svgRender->render(&p);
+        iconlabel->setPixmap(*pixmap);
+        iconlabel->setFixedSize(pixmap->size());
+        textlabel->setStyleSheet("background:transparent;color:#ffffff;");
+        textlabel->adjustSize();
+        is_pressed=true;
+    }
+    else{
+        delete svgRender;
+        svgRender = new QSvgRenderer(this);
+        svgRender->load(iconstr);
+        pixmap=new QPixmap(iconSize,iconSize);
+        pixmap->fill(Qt::transparent);
+        QPainter p(pixmap);
+        svgRender->render(&p);
+        iconlabel->setPixmap(*pixmap);
+        iconlabel->setFixedSize(pixmap->size());
+        textlabel->setStyleSheet("background:transparent;color:rgba(255, 255, 255,50%);");
+        textlabel->adjustSize();
+        is_pressed=false;
+    }
+}
