@@ -39,7 +39,7 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     if(index.isValid())
     {
         painter->save();
-
+        QStyleOptionViewItem viewOption(option);//用来在视图中画一个item
         QRectF rect;
         rect.setX(option.rect.x());
         rect.setY(option.rect.y());
@@ -59,13 +59,13 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
         path.quadTo(rect.topRight(), rect.topRight() + QPointF(-radius, -0));
 
 
-        QFont font;
+//        QFont font;
 //        font.setFamily("Microsoft YaHei");
 
-        font.setPixelSize(14);
-        painter->setFont(font);
+//        font.setPixelSize(Style::AppListFontSize);
+//        painter->setFont(font);
 
-        QIcon icon=index.model()->data(index,Qt::DecorationRole).value<QIcon>();
+//        QIcon icon=index.model()->data(index,Qt::DecorationRole).value<QIcon>();
         QStringList strlist=index.model()->data(index,Qt::DisplayRole).toStringList();
 //        if(!icon.isNull())
 //            painter->fillRect(QRect(rect.x(),rect.y(),40,40),QColor(Qt::blue));//图片加背景
@@ -88,6 +88,12 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             if(strlist.at(1).toInt()==1)
             {
                 QRect iconRect=QRect(rect.x()+11,rect.y()+(rect.height()-32)/2,32,32);
+                QString iconstr=pUkuiMenuInterface->getAppIcon(strlist.at(0));
+                iconstr.remove(".png");
+                iconstr.remove(".svg");
+                QIcon icon=QIcon::fromTheme(iconstr);
+                if(icon.isNull())
+                    icon=QIcon::fromTheme(QString("application-x-desktop"));
                 icon.paint(painter,iconRect);
                 painter->setPen(QPen(Qt::white));
                 QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
@@ -98,7 +104,8 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             else
             {
                 painter->setPen(QPen(Qt::white));
-                QRect textRect=QRect(rect.x()+11,rect.y()+(rect.height()-14)/2,strlist.at(0).size()*14,14);
+//                QRect textRect=QRect(rect.x()+11,rect.y()+(rect.height()-14)/2,strlist.at(0).size()*14,14);
+                QRect textRect=QRect(rect.x()+11,rect.y(),rect.width(),rect.height());
                 painter->drawText(textRect,Qt::AlignVCenter,strlist.at(0));
                 painter->setRenderHint(QPainter::Antialiasing, true);
                 painter->setPen(QPen(QColor("#FFFFFF"),1));
@@ -109,17 +116,22 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
         }
         else
         {
-            setting->beginGroup("application");
+            setting->beginGroup("lockapplication");
             QRect iconRect=QRect(rect.left()+11,rect.y()+(rect.height()-32)/2,32,32);
+            QString iconstr=pUkuiMenuInterface->getAppIcon(strlist.at(0));
+            iconstr.remove(".png");
+            iconstr.remove(".svg");
+            QIcon icon=QIcon::fromTheme(iconstr);
+            if(icon.isNull())
+                icon=QIcon::fromTheme(QString("application-x-desktop"));
             icon.paint(painter,iconRect);
-
             QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
             QFileInfo fileInfo(strlist.at(0));
             QString desktopfn=fileInfo.fileName();
-            if(setting->value(desktopfn).toInt()==0)
+            if(setting->contains(desktopfn))
             {
                 QIcon icon(QString(":/data/img/mainviewwidget/lock.svg"));
-                icon.paint(painter,QRect(iconRect.topRight().x()-7,iconRect.topRight().y()-2,12,12));
+                icon.paint(painter,QRect(rect.topRight().x()-22,rect.y()+(rect.height()-16)/2,16,16));
             }
             painter->setOpacity(1);
             painter->setPen(QPen(Qt::white));
@@ -132,3 +144,8 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     }
 
 }
+
+QSize ItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+    return QSize(296,48);
+}
