@@ -63,39 +63,41 @@ void ListView::initWidget()
     this->setViewMode(QListView::ListMode);
     this->setContextMenuPolicy(Qt::CustomContextMenu);
     this->setFocusPolicy(Qt::NoFocus);
+    this->setMovement(QListView::Static);
     connect(this,SIGNAL(customContextMenuRequested(QPoint)),this,SLOT(rightClickedSlot()));
     connect(this,SIGNAL(clicked(QModelIndex)),this,SLOT(onClicked(QModelIndex)));
 
 }
 
-//void ListView::addData(QVector<QStringList> data, QStringList rowlist)
-//{
-//    this->rowlist.clear();
-//    model=new ListModel(this);
-//    this->setModel(model);
-//    model->setData(data);
-//    this->rowlist=rowlist;
-//}
-
 void ListView::addData(QVector<QStringList> data)
 {
-    model=new ListModel(this);
-    this->setModel(model);
-    model->setData(data);
+    listmodel=new QStandardItemModel(this);
+    this->setModel(listmodel);
+    Q_FOREACH(QStringList desktopfp,data)
+    {
+        QStandardItem* item=new QStandardItem;
+        item->setData(QVariant::fromValue<QStringList>(desktopfp),Qt::DisplayRole);
+        listmodel->appendRow(item);
+    }
+    m_delegate= new ItemDelegate(this,module);
+    this->setItemDelegate(m_delegate);
 }
 
 void ListView::updateData(QVector<QStringList> data)
 {
-//    qDebug()<<model->rowCount();
-//    model->removeRows(0,model->rowCount());
-//    qDebug()<<model->rowCount()<<data.size();
-//    model->setData(data);
-    model->updateData(data);
+    listmodel->clear();
+    Q_FOREACH(QStringList desktopfp,data)
+    {
+        QStandardItem* item=new QStandardItem;
+        item->setData(QVariant::fromValue<QStringList>(desktopfp),Qt::DisplayRole);
+        listmodel->appendRow(item);
+    }
+
 }
 
 void ListView::onClicked(QModelIndex index)
 {
-     QVariant var = model->data(index, Qt::DisplayRole);
+     QVariant var = listmodel->data(index, Qt::DisplayRole);
      if(var.isValid())
      {
 //         qDebug()<<var.value<QStringList>()<<index.row();
@@ -110,64 +112,77 @@ void ListView::rightClickedSlot()
     {
         menu=new RightClickMenu(this);
         QModelIndex index=this->currentIndex();
-        QVariant var=model->data(index, Qt::DisplayRole);
+        QVariant var=listmodel->data(index, Qt::DisplayRole);
         QStringList strlist=var.value<QStringList>();
         if(module>0)
         {
             if(strlist.at(1).toInt()==1)
             {
-                QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
-                int ret=menu->showAppBtnMenu(appname);
-                if(ret==1 || ret==2)
-                    Q_EMIT sendFixedOrUnfixedSignal();
+                int ret=menu->showAppBtnMenu(strlist.at(0));
+                if(ret==1)
+                    Q_EMIT sendFixedOrUnfixedSignal(strlist.at(0),0);
+                if(ret==2)
+                    Q_EMIT sendFixedOrUnfixedSignal(strlist.at(0),1);
+                if(ret==6)
+                    Q_EMIT sendHideMainWindowSignal();
                 if(ret==7)
                     Q_EMIT sendHideMainWindowSignal();
             }
         }
         else{
-            QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
-            int ret=menu->showCommonUseAppBtnMenu(appname);
-            if(ret==1 || ret==2)
+            int ret=menu->showCommonUseAppBtnMenu(strlist.at(0));
+            if(ret==1)
             {
                 this->setCurrentIndex(index);
+                listmodel->removeRow(index.row());
+                setting->beginGroup("lockapplication");
+                QStandardItem* item=new QStandardItem;
+                item->setData(QVariant::fromValue<QStringList>(strlist),Qt::DisplayRole);
+                listmodel->insertRow(setting->allKeys().size()-1,item);
+                setting->endGroup();
+                Q_EMIT sendUpdateAppListSignal(strlist.at(0),0);
+            }
+            if(ret==2)
+            {
+                listmodel->removeRow(index.row());
+                setting->beginGroup("lockapplication");
+                QStandardItem* item=new QStandardItem;
+                item->setData(QVariant::fromValue<QStringList>(strlist),Qt::DisplayRole);
+                listmodel->insertRow(setting->allKeys().size(),item);
+                setting->endGroup();
+                Q_EMIT sendUpdateAppListSignal(strlist.at(0),1);
             }
 
             if(ret==7)
                 Q_EMIT sendHideMainWindowSignal();
 
-            if(ret==8 || ret==9)
+            if(ret==8)
             {
-                QStringList keys;
-                keys.clear();
-                setting->beginGroup("application");
-                keys=setting->childKeys();
-                QStringList applist;
-                applist.clear();
-                for(int i=0;i<keys.count();i++)
-                {
-                    int val=setting->value(keys.at(i)).toInt();
-                    if(val==2 || val==0)
-                        applist.append(keys.at(i));
-                }
-
-                data.clear();
-                for(int i=0;i<applist.count();i++)
-                {
-//                    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(applist.at(i));
-                    QString desktopfp=QString("/usr/share/applications/"+applist.at(i));
-                    data.append(QStringList()<<desktopfp<<"1");
-                }
-
-                this->updateData(data);
-                setting->endGroup();
-
-                Q_EMIT sendUpdateAppListSignal();
+                listmodel->removeRow(index.row());
+                Q_EMIT removeListItemSignal(strlist.at(0));
             }
+            if(ret==9)
+            {
+                setting->beginGroup("lockapplication");
+                for(int i=listmodel->rowCount()-1;i>=0;i--)
+                {
+                    QVariant var=listmodel->index(i,0).data(Qt::DisplayRole);
+                    QString desktopfp=var.value<QStringList>().at(0);
+                    QFileInfo fileInfo(desktopfp);
+                    QString desktopfn=fileInfo.fileName();
+                    if(!setting->contains(desktopfn))
+                        listmodel->removeRow(i);
+                }
+                setting->endGroup();
+                Q_EMIT removeListAllItemSignal();
+            }
+
+            if(ret==6)
+                Q_EMIT sendHideMainWindowSignal();
         }
 
         this->selectionModel()->clear();
     }
-
 }
 
 void ListView::enterEvent(QEvent *e)
