@@ -22,11 +22,12 @@
 #include <QStandardItem>
 #include <QEvent>
 #include <QScrollBar>
-#include "listmodel.h"
+#include <QStandardItemModel>
 #include "src/Style/style.h"
 #include "src/RightClickMenu/rightclickmenu.h"
 #include <QSettings>
 #include "src/Interface/ukuimenuinterface.h"
+#include "itemdelegate.h"
 
 class ListView : public QListView
 {
@@ -35,7 +36,6 @@ public:
     ListView(QWidget *parent, int width, int height, int module);
     ~ListView();
 
-//    void addData(QVector<QStringList> data,QStringList rowlist);//字母排序模块添加数据
     void addData(QVector<QStringList> data);
     void updateData(QVector<QStringList> data);
 
@@ -45,16 +45,16 @@ protected:
     void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;
 
 private:
-    ListModel* model=nullptr;
+    QStandardItemModel* listmodel=nullptr;
     int w=0;
     int h=0;
     int module=0;
     UkuiMenuInterface* pUkuiMenuInterface=nullptr;
-//    QStringList rowlist;//存放分类字母所在行
 
-    RightClickMenu* menu;//右键菜单
+    RightClickMenu* menu=nullptr;//右键菜单
     QSettings *setting=nullptr;
     QVector<QStringList> data;
+    ItemDelegate* m_delegate=nullptr;
 
 private Q_SLOTS:
     void onClicked(QModelIndex index);//点击item
@@ -62,8 +62,10 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void sendItemClickedSignal(QStringList arg);//向字母排序或功能分类模块发送item点击信号
-    void sendFixedOrUnfixedSignal();//向字母排序、功能分类发送固定或者取消固定信号
-    void sendUpdateAppListSignal();//向CommonUseWidget发送更新应用列表信号
+    void sendFixedOrUnfixedSignal(QString desktopfp,int type);//向字母排序、功能分类发送固定或者取消固定信号
+    void sendUpdateAppListSignal(QString desktopfp,int type);//向CommonUseWidget发送更新应用列表信号
+    void removeListItemSignal(QString desktopfp);
+    void removeListAllItemSignal();
     void sendHideMainWindowSignal();
 };
 
